(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    287624,       6951]
NotebookOptionsPosition[    280041,       6715]
NotebookOutlinePosition[    282065,       6784]
CellTagsIndexPosition[    282022,       6781]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["CustomTicks package",
  FontFamily->"Times New Roman",
  FontSize->36],
 StyleBox["\n",
  FontFamily->"Times New Roman"],
 StyleBox["Mark A. Caprio, Department of Physics, University of Notre Dame", 
  "SmallText",
  FontFamily->"Times New Roman",
  FontSize->12],
 "\nVersion 2.1.0 (March 12, 2016) "
}], "Text",
 CellFrame->{{0, 0}, {2, 0}},
 CellChangeTimes->{{3.4247304725625*^9, 3.424730482609375*^9}, {
   3.42585660284375*^9, 3.425856606109375*^9}, {3.431818235890625*^9, 
   3.431818240796875*^9}, {3.516133792453125*^9, 3.516133799984375*^9}, {
   3.5264206845625*^9, 3.526420694140625*^9}, {3.566838279130357*^9, 
   3.566838285018366*^9}, {3.6141979980079308`*^9, 3.6141980022199383`*^9}, {
   3.6142013749739585`*^9, 3.6142013863339744`*^9}, {3.6216273119876413`*^9, 
   3.621627313282443*^9}, 3.6216279493535705`*^9, {3.666800251973149*^9, 
   3.6668002625499673`*^9}},
 Hyphenation->False],

Cell["\<\
Notebook notes:
\tStyleSheet is HelpBrowser.
\tNotebook options: \"Cell Options\">>\"Display Options\">>\"Cell Element \
Spacings\">>\"ClosedCellHeight\"->1
\tHyphenation: LanguageCategory set to None is supposed to prevent \
hyphenation but does not seem to work as advertised.  Setting Hyphenation to \
None also fails.  Each cell's Hyphenation option must be set to None.
\tBefore distribution: update version number in footer, convert all -> to \
\[Rule] in running text; set AppendTo directory argument to c:\\\\example, \
select all cells and set \"Formatting Options\">>\"Text Layout\">>Hyphenation \
to None; unset options Editable and Deletable\
\>", "Text",
 CellOpen->False,
 Hyphenation->False],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell[TextData[{
 "\t",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides a powerful system for generating graphics but does not provide, \
in built-in form, the fine formatting control necessary for the preparation \
of publication quality figures.  The CustomTicks package provides detailed \
customization of tick mark placement and formatting.  The flexibility \
achieved matches or exceeds that available with most commercial scientific \
plotting software.  Linear, logarithmic, and general nonlinear axes are \
supported.  Some tick mark manipulation functions, for use in graphics \
programming, are also provided by the CustomTicks package."
}], "Text"],

Cell[TextData[{
 "\tThe CustomTicks package is part of the SciDraw system for preparing \
publication-quality scientific figures with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " (",
 StyleBox["http://scidraw.nd.edu",
  FontFamily->"Courier New"],
 ").  It was originally developed as part of LevelScheme [Comput. Phys. \
Commun. ",
 StyleBox["171",
  FontWeight->"Bold"],
 ", 107 (2005)]."
}], "Text",
 CellChangeTimes->{
  3.51613434028125*^9, {3.6216273183680525`*^9, 3.6216275211234136`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic use for linear axes", "Subsubsection"],

Cell[TextData[{
 "\t The default tick marks produced by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s plotting functions are typically not ideal for publication.  It is often \
desirable to be able to change the tick spacing from that selected by ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"],
 "  The tick marks are also often too short to be easily visible."
}], "Text",
 CellChangeTimes->{{3.51613436621875*^9, 3.5161343939375*^9}, {
  3.516134432953125*^9, 3.51613459659375*^9}}],

Cell[TextData[{
 "\tIt is possible to override the default ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ticks by specifying a list of tick marks, complete with formatting \
information, as the value for the ",
 StyleBox["Ticks",
  FontFamily->"Courier New"],
 " or ",
 StyleBox["FrameTicks",
  FontFamily->"Courier New"],
 " option (see the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for basic plotting options).  It is prohibitively tedious to \
construct such lists by hand.  The CustomTicks package provides functions to \
automatically construct lists of tick marks, with detailed control over \
formatting."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces linear tick specifications, with automatically chosen \
major and minor tick intervals\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<interval\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<subdivs\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces linear tick specifications, with manually chosen major \
and minor tick intervals\>\"", "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Tick specification function.\>\"", "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{-Infinity,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits the drawing of ticks (and their labels) to given \
coordinate range\>\"", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowMinorTicks\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Controls whether or not the minor ticks are drawn; mainly for use \
with \>\"", ",", " ", 
      RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
      "\"\< (see below)\>\""}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Options controlling the coordinates at which tick marks are \
displayed.\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowTickLabels\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not major tick labels are printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowMinorTickLabels\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not minor tick labels are printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{-Infinity,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits printing of major tick labels to given coordinate \
range\>\"", "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowFirst\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not first major tick label is printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowLast\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not last major tick label is printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<1\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Limits printing of major tick labels to one in every \>\"", ",", 
      " ", 
      RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], ",", 
      "\"\< major ticks\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelStart\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Used in conjunction with \>\"", ",", " ", 
      RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], ",", 
      "\"\< chooses which subset of major tick labels are printed\>\""}], 
     "}"}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{
    "{", "\"\<Options controlling which tick marks are accompanied by labels.\
\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MajorTickLength\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0.01\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Length for the major ticks (may also be given as a list of two \
lengths, into and out of the frame, as described in the Mathematica \
documentation for \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Ticks\>\"", "]"}], ",", "\"\<)\>\""}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickLength\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0.005\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Length for the minor ticks (may also be given as a list of two \
lengths, into and out of the frame, as described in the Mathematica \
documentation for \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Ticks\>\"", "]"}], ",", "\"\<)\>\""}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickDirection\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<In\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Orientation of tick marks (\>\"", ",", 
      RowBox[{"texttt", "[", "\"\<In\>\"", "]"}], ",", 
      "\"\< for tick marks into the frame, \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Out\>\"", "]"}], ",", 
      "\"\<for tick marks out of the frame, or \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<All\>\"", "]"}], ",", 
      "\"\<for tick marks both into and out of the frame)\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLengthScale\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<1\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Additional scale factor by which to lengthen both the major and \
minor ticks, relative to the lengths given by the options \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<MajorTickLength\>\"", "]"}], ",", 
      "\"\< and \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<MinorTickLength\>\"", "]"}], ",", 
      "\"\< above\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MajorTickStyle\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<List specifying the line style for the major ticks\>\"", "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickStyle\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<List specifying the line style for the minor ticks\>\"", 
     "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{
    "{", "\"\<Options specifying the appearance of tick marks.\>\"", "}"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<DecimalDigits\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Sets number of digits after decimal place for major tick labels; if \
\>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], ",", 
      "\"\<, the maximum number of digits needed for any label is used for \
all labels\>\""}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<NumberSigns\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Strings to use as signs for negative and positive numbers; see \
\>\"", ",", 
      RowBox[{"textit", "[", "\"\<Mathematica\>\"", "]"}], ",", 
      "\"\<documentation and discussion of \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<FixedPointForm\>\"", "]"}], ",", 
      "\"\< function below\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<NumberPoint\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<\\\".\\\"\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", "\"\<String to use as decimal point\>\"", "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Options specifying the numerical formatting of tick labels (if \
the default labeling function is used).\>\"", "}"}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 InitializationCell->True,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQzdAwSVnW7ZUjQ8NebTDNwGcA4W+E0AwLrCD09UAI
/S0PIj+xDEJ37IWIP7wC4e+8AeEbPoLwhZ9D6Ol/IOKpbHJg+qgMhE5WAtMN
jRCa4eUFCF1xGUS7xJ9Q6Xz7ynFZ5gRNEK1h9FMPRLvftLUF0XHB81xA9Pcl
XAEgek5xSiiIdjnzJwxEP7G6EAWiy7KLE0B0w5WeVBDdavs3DUS/nXbDrhtI
71itbg+i8w0iXt4NfO24yrbgFYhuM3nAcw9If/Z3EwDRACJYirI=
  "],
 Hyphenation->False,
 CellLabel->"In[22]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "linear", " ", "tick", " ", "specifications"}], ",", 
        " ", 
        RowBox[{
        "with", " ", "automatically", " ", "chosen", " ", "major", " ", "and",
          " ", "minor", " ", "tick", " ", "intervals"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["interval",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["subdivs",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "linear", " ", "tick", " ", "specifications"}], ",", 
        " ", 
        RowBox[{
        "with", " ", "manually", " ", "chosen", " ", "major", " ", "and", " ",
          "minor", " ", "tick", " ", "intervals"}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801288114*^9}],

Cell["Tick specification function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801303714*^9}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["TickRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "the", " ", "drawing", " ", "of", " ", "ticks", " ", 
        RowBox[{"(", 
         RowBox[{"and", " ", "their", " ", "labels"}], ")"}], " ", "to", " ", 
        "given", " ", "coordinate", " ", "range"}]},
      {
       StyleBox["ShowMinorTicks",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Controls", " ", "whether", " ", "or", " ", "not", " ", "the", " ", 
          "minor", " ", "ticks", " ", "are", " ", "drawn"}], ";", " ", 
         RowBox[{"mainly", " ", "for", " ", "use", " ", "with", " "}]}], 
        StyleBox["LogTicks",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"(", 
          RowBox[{"see", " ", "below"}], ")"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801303714*^9}],

Cell["\<\
Options controlling the coordinates at which tick marks are displayed.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801319314*^9}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["ShowTickLabels",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "major", " ", 
        "tick", " ", "labels", " ", "are", " ", "printed"}]},
      {
       StyleBox["ShowMinorTickLabels",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "minor", " ", 
        "tick", " ", "labels", " ", "are", " ", "printed"}]},
      {
       StyleBox["TickLabelRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "printing", " ", "of", " ", "major", " ", "tick", " ", 
        "labels", " ", "to", " ", "given", " ", "coordinate", " ", "range"}]},
      {
       StyleBox["ShowFirst",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "first", " ", 
        "major", " ", "tick", " ", "label", " ", "is", " ", "printed"}]},
      {
       StyleBox["ShowLast",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "last", " ", 
        "major", " ", "tick", " ", "label", " ", "is", " ", "printed"}]},
      {
       StyleBox["TickLabelStep",
        FontFamily->"Courier"], 
       StyleBox["1",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Limits", " ", "printing", " ", "of", " ", "major", " ", "tick", " ", 
         "labels", " ", "to", " ", "one", " ", "in", " ", "every", " "}], 
        StyleBox["TickLabelStep",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"major", " ", "ticks"}]}]}]},
      {
       StyleBox["TickLabelStart",
        FontFamily->"Courier"], 
       StyleBox["0",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{"Used", " ", "in", " ", "conjunction", " ", "with", " "}], 
        StyleBox["TickLabelStep",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{
         "chooses", " ", "which", " ", "subset", " ", "of", " ", "major", " ",
           "tick", " ", "labels", " ", "are", " ", "printed"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801319314*^9}],

Cell["\<\
Options controlling which tick marks are accompanied by labels.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801319314*^9}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["MajorTickLength",
        FontFamily->"Courier"], 
       StyleBox["0.01",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Length", " ", "for", " ", "the", " ", "major", " ", "ticks", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "may", " ", "also", " ", "be", " ", "given", " ", "as", " ", "a", 
            " ", "list", " ", "of", " ", "two", " ", "lengths"}], ",", " ", 
           RowBox[{
           "into", " ", "and", " ", "out", " ", "of", " ", "the", " ", 
            "frame"}], ",", " ", 
           RowBox[{
           "as", " ", "described", " ", "in", " ", "the", " ", "Mathematica", 
            " ", "documentation", " ", "for", " "}]}]}]}], 
        StyleBox["Ticks",
         FontFamily->"Courier"], ")"}]},
      {
       StyleBox["MinorTickLength",
        FontFamily->"Courier"], 
       StyleBox["0.005",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Length", " ", "for", " ", "the", " ", "minor", " ", "ticks", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "may", " ", "also", " ", "be", " ", "given", " ", "as", " ", "a", 
            " ", "list", " ", "of", " ", "two", " ", "lengths"}], ",", " ", 
           RowBox[{
           "into", " ", "and", " ", "out", " ", "of", " ", "the", " ", 
            "frame"}], ",", " ", 
           RowBox[{
           "as", " ", "described", " ", "in", " ", "the", " ", "Mathematica", 
            " ", "documentation", " ", "for", " "}]}]}]}], 
        StyleBox["Ticks",
         FontFamily->"Courier"], ")"}]},
      {
       StyleBox["TickDirection",
        FontFamily->"Courier"], 
       StyleBox["In",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Orientation", " ", "of", " ", "tick", " ", "marks", " ", "("}], 
        StyleBox["In",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{
          RowBox[{
          "for", " ", "tick", " ", "marks", " ", "into", " ", "the", " ", 
           "frame"}], ",", " "}]}], 
        StyleBox["Out",
         FontFamily->"Courier"], 
        RowBox[{
         RowBox[{
         "for", " ", "tick", " ", "marks", " ", "out", " ", "of", " ", "the", 
          " ", "frame"}], ",", " ", "or", " "}], 
        StyleBox["All",
         FontFamily->"Courier"], 
        RowBox[{
         RowBox[{
         "for", " ", "tick", " ", "marks", " ", "both", " ", "into", " ", 
          "and", " ", "out", " ", "of", " ", "the", " ", "frame"}], ")"}]}]},
      {
       StyleBox["TickLengthScale",
        FontFamily->"Courier"], 
       StyleBox["1",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Additional", " ", "scale", " ", "factor", " ", "by", " ", "which", 
          " ", "to", " ", "lengthen", " ", "both", " ", "the", " ", "major", 
          " ", "and", " ", "minor", " ", "ticks"}], ",", " ", 
         RowBox[{
         "relative", " ", "to", " ", "the", " ", "lengths", " ", "given", " ",
           "by", " ", "the", " ", "options", " "}]}], 
        StyleBox["MajorTickLength",
         FontFamily->"Courier"], 
        RowBox[{" ", "and", " "}], 
        StyleBox["MinorTickLength",
         FontFamily->"Courier"], 
        RowBox[{" ", "above"}]}]},
      {
       StyleBox["MajorTickStyle",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "List", " ", "specifying", " ", "the", " ", "line", " ", "style", " ", 
        "for", " ", "the", " ", "major", " ", "ticks"}]},
      {
       StyleBox["MinorTickStyle",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "List", " ", "specifying", " ", "the", " ", "line", " ", "style", " ", 
        "for", " ", "the", " ", "minor", " ", "ticks"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801334914*^9}],

Cell["Options specifying the appearance of tick marks.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801334914*^9}],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["DecimalDigits",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Sets", " ", "number", " ", "of", " ", "digits", " ", "after", " ", 
          "decimal", " ", "place", " ", "for", " ", "major", " ", "tick", " ",
           "labels"}], ";", " ", "if", " "}], 
        StyleBox["Automatic",
         FontFamily->"Courier"], 
        RowBox[{",", " ", 
         RowBox[{
         "the", " ", "maximum", " ", "number", " ", "of", " ", "digits", " ", 
          "needed", " ", "for", " ", "any", " ", "label", " ", "is", " ", 
          "used", " ", "for", " ", "all", " ", "labels"}]}]}]},
      {
       StyleBox["NumberSigns",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Strings", " ", "to", " ", "use", " ", "as", " ", "signs", " ", 
          "for", " ", "negative", " ", "and", " ", "positive", " ", 
          "numbers"}], ";", " ", "see", " "}], 
        StyleBox["Mathematica",
         FontSlant->"Italic"], 
        RowBox[{
        "documentation", " ", "and", " ", "discussion", " ", "of", " "}], 
        StyleBox["FixedPointForm",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"function", " ", "below"}]}]}]},
      {
       StyleBox["NumberPoint",
        FontFamily->"Courier"], 
       StyleBox["\<\".\"\>",
        FontFamily->"Courier"], 
       RowBox[{
       "String", " ", "to", " ", "use", " ", "as", " ", "decimal", " ", 
        "point"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801334914*^9}],

Cell["\<\
Options specifying the numerical formatting of tick labels (if the default \
labeling function is used).\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.666800801350514*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Logarithmic axes", "Subsubsection"],

Cell[TextData[{
 "\tThe function ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " generates tick marks for logarithmic axes.  ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " can produce tick marks for an arbitrary logarithmic base (10 is the \
default, but ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and 2 are other commonly useful bases).  Unlike the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " function, which produces cumbersome decimal labels (",
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", \"0.0000001\", \"0.000001\", \[Ellipsis]), ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " produces true exponential labels (",
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", \"",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "7"}]], TraditionalForm]]],
 "\", \"",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]]],
 "\", \[Ellipsis])."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LogTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces logarithmic tick specifications, base 10\>\"", "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LogTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<base\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Produces logarithmic tick specifications, arbitrary \>\"", ",", 
      RowBox[{"textit", "[", "\"\<base\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{"{", "\"\<Logarithmic tick specification function.\>\"", "}"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 Hyphenation->False,
 CellLabel->"In[73]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LogTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["n1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "logarithmic", " ", "tick", " ", "specifications"}], 
        ",", " ", 
        RowBox[{"base", " ", "10"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"LogTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["base",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "logarithmic", " ", "tick", " ", "specifications"}], 
        ",", " ", 
        RowBox[{"arbitrary", " ", 
         StyleBox["base",
          FontSlant->"Italic"]}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Logarithmic tick specification function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 "\t",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must be given the starting power, ending power, and, optionally, the \
logarithmic base ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  For base 10, a total of eight minor ticks are produced in each major \
interval, at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Cross]", 
    SuperscriptBox["10", "n"]}], TraditionalForm]]],
 " through ",
 Cell[BoxData[
  FormBox[
   RowBox[{"9", "\[Cross]", 
    SuperscriptBox["10", "n"]}], TraditionalForm]]],
 ".  For an arbitrary base ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", \[LeftCeiling]",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[RightCeiling]-2 minor ticks are produced, at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Cross]", 
    SuperscriptBox["b", "n"]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[Cross]", 
    SuperscriptBox["b", "n"]}], TraditionalForm]]],
 ", \[Ellipsis].  Display of the minor ticks may be suppressed by specifying \
the option ",
 StyleBox["ShowMinorTicks\[Rule]False",
  FontFamily->"Courier New"],
 ".  Some ",
 "examples are shown below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CodeOpts", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ManualLabel", ",", 
       RowBox[{"Offset", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"+", "1"}]}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "1", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{"0", ",", "2"}], "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Base 10\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", "\"\<LogTicks[0,2]\>\"", ",", 
       "CodeOpts"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "2.2", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", 
          RowBox[{"TickLabelStep", "\[Rule]", "4"}], ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "/", "8"}], "+", "1"}], ")"}], "&"}], ")"}]}]}], 
         "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Skipped labels\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<LogTicks[-8,8,\>\"", ",", "\"\<TickLabelStep\[Rule]4]\>\""}], 
          "}"}]}], "]"}], ",", "CodeOpts"}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "3.5", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", 
          RowBox[{"ShowMinorTicks", "\[Rule]", "False"}], ",", 
          RowBox[{"TickLabelStep", "\[Rule]", "4"}], ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "/", "8"}], "+", "1"}], ")"}], "&"}], ")"}]}]}], 
         "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<No minor ticks\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<LogTicks[-8,8,\>\"", ",", 
           "\"\<ShowMinorTicks\[Rule]False,\>\"", ",", 
           "\"\<TickLabelStep\[Rule]4]\>\""}], "}"}]}], "]"}], ",", 
       "CodeOpts"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "4.8", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{"E", ",", "0", ",", "4", ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"#", "/", "2"}], ")"}], "&"}], ")"}]}]}], "]"}]}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<Base \>\"", ",", 
          RowBox[{"textit", "[", "\"\<e\>\"", "]"}]}], "}"}], "]"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", "\"\<LogTicks[E,0,4]\>\"", ",", 
       "CodeOpts"}], "]"}], ","}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "5.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", 
     RowBox[{"{", 
      RowBox[{"6.5", ",", "3.5"}], "}"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.526233101546875*^9, 3.52623312053125*^9}, {
  3.52623315465625*^9, 3.5262331549375*^9}, {3.5262332785625*^9, 
  3.526233283859375*^9}, {3.526421732328125*^9, 3.52642174503125*^9}},
 CellLabel->"In[13]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{0.9999999999999998, 0.}, {0.9999999999999998, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{0.9679423076923075, 2.204742857142857}, {
     0.9999999999999998, 2.3}, {1.032057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{1.0384692307692305`, 0.}, {0.9999999999999998, 0.}}], 
    LineBox[{{1.0384692307692305`, 1.}, {0.9999999999999998, 1.}}], 
    LineBox[{{1.0384692307692305`, 2.}, {0.9999999999999998, 2.}}], 
    LineBox[{{1.0192346153846152`, 0.30102999566398114`}, {0.9999999999999998,
      0.30102999566398114`}}], 
    LineBox[{{1.0192346153846152`, 0.4771212547196624}, {0.9999999999999998, 
     0.4771212547196624}}], 
    LineBox[{{1.0192346153846152`, 0.6020599913279623}, {0.9999999999999998, 
     0.6020599913279623}}], 
    LineBox[{{1.0192346153846152`, 0.6989700043360186}, {0.9999999999999998, 
     0.6989700043360186}}], 
    LineBox[{{1.0192346153846152`, 0.7781512503836435}, {0.9999999999999998, 
     0.7781512503836435}}], 
    LineBox[{{1.0192346153846152`, 0.8450980400142567}, {0.9999999999999998, 
     0.8450980400142567}}], 
    LineBox[{{1.0192346153846152`, 0.9030899869919433}, {0.9999999999999998, 
     0.9030899869919433}}], 
    LineBox[{{1.0192346153846152`, 0.9542425094393248}, {0.9999999999999998, 
     0.9542425094393248}}], 
    LineBox[{{1.0192346153846152`, 1.3010299956639813`}, {0.9999999999999998, 
     1.3010299956639813`}}], 
    LineBox[{{1.0192346153846152`, 1.4771212547196624`}, {0.9999999999999998, 
     1.4771212547196624`}}], 
    LineBox[{{1.0192346153846152`, 1.6020599913279623`}, {0.9999999999999998, 
     1.6020599913279623`}}], 
    LineBox[{{1.0192346153846152`, 1.6989700043360187`}, {0.9999999999999998, 
     1.6989700043360187`}}], 
    LineBox[{{1.0192346153846152`, 1.7781512503836434`}, {0.9999999999999998, 
     1.7781512503836434`}}], 
    LineBox[{{1.0192346153846152`, 1.8450980400142567`}, {0.9999999999999998, 
     1.8450980400142567`}}], 
    LineBox[{{1.0192346153846152`, 1.9030899869919433`}, {0.9999999999999998, 
     1.9030899869919433`}}], 
    LineBox[{{1.0192346153846152`, 1.9542425094393248`}, {0.9999999999999998, 
     1.9542425094393248`}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.1999999999999997`, 0.}, {2.1999999999999997`, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.1679423076923072`, 2.204742857142857}, {
     2.1999999999999993`, 2.3}, {2.232057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.2384692307692307`, 0.}, {2.1999999999999997`, 0.}}], 
    LineBox[{{2.2384692307692307`, 0.125}, {2.1999999999999997`, 0.125}}], 
    LineBox[{{2.2384692307692307`, 0.25}, {2.1999999999999997`, 0.25}}], 
    LineBox[{{2.2384692307692307`, 0.375}, {2.1999999999999997`, 0.375}}], 
    LineBox[{{2.2384692307692307`, 0.5}, {2.1999999999999997`, 0.5}}], 
    LineBox[{{2.2384692307692307`, 0.625}, {2.1999999999999997`, 0.625}}], 
    LineBox[{{2.2384692307692307`, 0.75}, {2.1999999999999997`, 0.75}}], 
    LineBox[{{2.2384692307692307`, 0.875}, {2.1999999999999997`, 0.875}}], 
    LineBox[{{2.2384692307692307`, 1.}, {2.1999999999999997`, 1.}}], 
    LineBox[{{2.2384692307692307`, 1.125}, {2.1999999999999997`, 1.125}}], 
    LineBox[{{2.2384692307692307`, 1.25}, {2.1999999999999997`, 1.25}}], 
    LineBox[{{2.2384692307692307`, 1.375}, {2.1999999999999997`, 1.375}}], 
    LineBox[{{2.2384692307692307`, 1.5}, {2.1999999999999997`, 1.5}}], 
    LineBox[{{2.2384692307692307`, 1.625}, {2.1999999999999997`, 1.625}}], 
    LineBox[{{2.2384692307692307`, 1.75}, {2.1999999999999997`, 1.75}}], 
    LineBox[{{2.2384692307692307`, 1.875}, {2.1999999999999997`, 1.875}}], 
    LineBox[{{2.2384692307692307`, 2.}, {2.1999999999999997`, 2.}}], 
    LineBox[{{2.219234615384615, 0.03762874945799766}, {2.1999999999999997`, 
     0.03762874945799766}}], 
    LineBox[{{2.219234615384615, 0.059640156839957825`}, {2.1999999999999997`,
      0.059640156839957825`}}], 
    LineBox[{{2.219234615384615, 0.07525749891599531}, {2.1999999999999997`, 
     0.07525749891599531}}], 
    LineBox[{{2.219234615384615, 0.08737125054200234}, {2.1999999999999997`, 
     0.08737125054200234}}], 
    LineBox[{{2.219234615384615, 0.09726890629795548}, {2.1999999999999997`, 
     0.09726890629795548}}], 
    LineBox[{{2.219234615384615, 0.10563725500178212`}, {2.1999999999999997`, 
     0.10563725500178212`}}], 
    LineBox[{{2.219234615384615, 0.11288624837399297`}, {2.1999999999999997`, 
     0.11288624837399297`}}], 
    LineBox[{{2.219234615384615, 0.11928031367991565`}, {2.1999999999999997`, 
     0.11928031367991565`}}], 
    LineBox[{{2.219234615384615, 0.16262874945799766`}, {2.1999999999999997`, 
     0.16262874945799766`}}], 
    LineBox[{{2.219234615384615, 0.18464015683995783`}, {2.1999999999999997`, 
     0.18464015683995783`}}], 
    LineBox[{{2.219234615384615, 0.2002574989159953}, {2.1999999999999997`, 
     0.2002574989159953}}], 
    LineBox[{{2.219234615384615, 0.21237125054200234`}, {2.1999999999999997`, 
     0.21237125054200234`}}], 
    LineBox[{{2.219234615384615, 0.22226890629795548`}, {2.1999999999999997`, 
     0.22226890629795548`}}], 
    LineBox[{{2.219234615384615, 0.23063725500178212`}, {2.1999999999999997`, 
     0.23063725500178212`}}], 
    LineBox[{{2.219234615384615, 0.23788624837399297`}, {2.1999999999999997`, 
     0.23788624837399297`}}], 
    LineBox[{{2.219234615384615, 0.24428031367991565`}, {2.1999999999999997`, 
     0.24428031367991565`}}], 
    LineBox[{{2.219234615384615, 0.28762874945799766`}, {2.1999999999999997`, 
     0.28762874945799766`}}], 
    LineBox[{{2.219234615384615, 0.3096401568399578}, {2.1999999999999997`, 
     0.3096401568399578}}], 
    LineBox[{{2.219234615384615, 0.3252574989159953}, {2.1999999999999997`, 
     0.3252574989159953}}], 
    LineBox[{{2.219234615384615, 0.33737125054200234`}, {2.1999999999999997`, 
     0.33737125054200234`}}], 
    LineBox[{{2.219234615384615, 0.3472689062979555}, {2.1999999999999997`, 
     0.3472689062979555}}], 
    LineBox[{{2.219234615384615, 0.3556372550017821}, {2.1999999999999997`, 
     0.3556372550017821}}], 
    LineBox[{{2.219234615384615, 0.36288624837399297`}, {2.1999999999999997`, 
     0.36288624837399297`}}], 
    LineBox[{{2.219234615384615, 0.36928031367991565`}, {2.1999999999999997`, 
     0.36928031367991565`}}], 
    LineBox[{{2.219234615384615, 0.41262874945799766`}, {2.1999999999999997`, 
     0.41262874945799766`}}], 
    LineBox[{{2.219234615384615, 0.4346401568399578}, {2.1999999999999997`, 
     0.4346401568399578}}], 
    LineBox[{{2.219234615384615, 0.4502574989159953}, {2.1999999999999997`, 
     0.4502574989159953}}], 
    LineBox[{{2.219234615384615, 0.46237125054200234`}, {2.1999999999999997`, 
     0.46237125054200234`}}], 
    LineBox[{{2.219234615384615, 0.4722689062979555}, {2.1999999999999997`, 
     0.4722689062979555}}], 
    LineBox[{{2.219234615384615, 0.4806372550017821}, {2.1999999999999997`, 
     0.4806372550017821}}], 
    LineBox[{{2.219234615384615, 0.48788624837399297`}, {2.1999999999999997`, 
     0.48788624837399297`}}], 
    LineBox[{{2.219234615384615, 0.49428031367991565`}, {2.1999999999999997`, 
     0.49428031367991565`}}], 
    LineBox[{{2.219234615384615, 0.5376287494579977}, {2.1999999999999997`, 
     0.5376287494579977}}], 
    LineBox[{{2.219234615384615, 0.5596401568399578}, {2.1999999999999997`, 
     0.5596401568399578}}], 
    LineBox[{{2.219234615384615, 0.5752574989159953}, {2.1999999999999997`, 
     0.5752574989159953}}], 
    LineBox[{{2.219234615384615, 0.5873712505420023}, {2.1999999999999997`, 
     0.5873712505420023}}], 
    LineBox[{{2.219234615384615, 0.5972689062979555}, {2.1999999999999997`, 
     0.5972689062979555}}], 
    LineBox[{{2.219234615384615, 0.6056372550017821}, {2.1999999999999997`, 
     0.6056372550017821}}], 
    LineBox[{{2.219234615384615, 0.612886248373993}, {2.1999999999999997`, 
     0.612886248373993}}], 
    LineBox[{{2.219234615384615, 0.6192803136799157}, {2.1999999999999997`, 
     0.6192803136799157}}], 
    LineBox[{{2.219234615384615, 0.6626287494579977}, {2.1999999999999997`, 
     0.6626287494579977}}], 
    LineBox[{{2.219234615384615, 0.6846401568399578}, {2.1999999999999997`, 
     0.6846401568399578}}], 
    LineBox[{{2.219234615384615, 0.7002574989159953}, {2.1999999999999997`, 
     0.7002574989159953}}], 
    LineBox[{{2.219234615384615, 0.7123712505420023}, {2.1999999999999997`, 
     0.7123712505420023}}], 
    LineBox[{{2.219234615384615, 0.7222689062979555}, {2.1999999999999997`, 
     0.7222689062979555}}], 
    LineBox[{{2.219234615384615, 0.7306372550017821}, {2.1999999999999997`, 
     0.7306372550017821}}], 
    LineBox[{{2.219234615384615, 0.737886248373993}, {2.1999999999999997`, 
     0.737886248373993}}], 
    LineBox[{{2.219234615384615, 0.7442803136799157}, {2.1999999999999997`, 
     0.7442803136799157}}], 
    LineBox[{{2.219234615384615, 0.7876287494579977}, {2.1999999999999997`, 
     0.7876287494579977}}], 
    LineBox[{{2.219234615384615, 0.8096401568399578}, {2.1999999999999997`, 
     0.8096401568399578}}], 
    LineBox[{{2.219234615384615, 0.8252574989159953}, {2.1999999999999997`, 
     0.8252574989159953}}], 
    LineBox[{{2.219234615384615, 0.8373712505420023}, {2.1999999999999997`, 
     0.8373712505420023}}], 
    LineBox[{{2.219234615384615, 0.8472689062979555}, {2.1999999999999997`, 
     0.8472689062979555}}], 
    LineBox[{{2.219234615384615, 0.8556372550017821}, {2.1999999999999997`, 
     0.8556372550017821}}], 
    LineBox[{{2.219234615384615, 0.862886248373993}, {2.1999999999999997`, 
     0.862886248373993}}], 
    LineBox[{{2.219234615384615, 0.8692803136799157}, {2.1999999999999997`, 
     0.8692803136799157}}], 
    LineBox[{{2.219234615384615, 0.9126287494579977}, {2.1999999999999997`, 
     0.9126287494579977}}], 
    LineBox[{{2.219234615384615, 0.9346401568399578}, {2.1999999999999997`, 
     0.9346401568399578}}], 
    LineBox[{{2.219234615384615, 0.9502574989159953}, {2.1999999999999997`, 
     0.9502574989159953}}], 
    LineBox[{{2.219234615384615, 0.9623712505420023}, {2.1999999999999997`, 
     0.9623712505420023}}], 
    LineBox[{{2.219234615384615, 0.9722689062979555}, {2.1999999999999997`, 
     0.9722689062979555}}], 
    LineBox[{{2.219234615384615, 0.9806372550017821}, {2.1999999999999997`, 
     0.9806372550017821}}], 
    LineBox[{{2.219234615384615, 0.987886248373993}, {2.1999999999999997`, 
     0.987886248373993}}], 
    LineBox[{{2.219234615384615, 0.9942803136799157}, {2.1999999999999997`, 
     0.9942803136799157}}], 
    LineBox[{{2.219234615384615, 1.0376287494579977`}, {2.1999999999999997`, 
     1.0376287494579977`}}], 
    LineBox[{{2.219234615384615, 1.0596401568399578`}, {2.1999999999999997`, 
     1.0596401568399578`}}], 
    LineBox[{{2.219234615384615, 1.0752574989159953`}, {2.1999999999999997`, 
     1.0752574989159953`}}], 
    LineBox[{{2.219234615384615, 1.0873712505420023`}, {2.1999999999999997`, 
     1.0873712505420023`}}], 
    LineBox[{{2.219234615384615, 1.0972689062979555`}, {2.1999999999999997`, 
     1.0972689062979555`}}], 
    LineBox[{{2.219234615384615, 1.1056372550017821`}, {2.1999999999999997`, 
     1.1056372550017821`}}], 
    LineBox[{{2.219234615384615, 1.112886248373993}, {2.1999999999999997`, 
     1.112886248373993}}], 
    LineBox[{{2.219234615384615, 1.1192803136799157`}, {2.1999999999999997`, 
     1.1192803136799157`}}], 
    LineBox[{{2.219234615384615, 1.1626287494579977`}, {2.1999999999999997`, 
     1.1626287494579977`}}], 
    LineBox[{{2.219234615384615, 1.1846401568399578`}, {2.1999999999999997`, 
     1.1846401568399578`}}], 
    LineBox[{{2.219234615384615, 1.2002574989159953`}, {2.1999999999999997`, 
     1.2002574989159953`}}], 
    LineBox[{{2.219234615384615, 1.2123712505420023`}, {2.1999999999999997`, 
     1.2123712505420023`}}], 
    LineBox[{{2.219234615384615, 1.2222689062979555`}, {2.1999999999999997`, 
     1.2222689062979555`}}], 
    LineBox[{{2.219234615384615, 1.2306372550017821`}, {2.1999999999999997`, 
     1.2306372550017821`}}], 
    LineBox[{{2.219234615384615, 1.237886248373993}, {2.1999999999999997`, 
     1.237886248373993}}], 
    LineBox[{{2.219234615384615, 1.2442803136799157`}, {2.1999999999999997`, 
     1.2442803136799157`}}], 
    LineBox[{{2.219234615384615, 1.2876287494579977`}, {2.1999999999999997`, 
     1.2876287494579977`}}], 
    LineBox[{{2.219234615384615, 1.3096401568399578`}, {2.1999999999999997`, 
     1.3096401568399578`}}], 
    LineBox[{{2.219234615384615, 1.3252574989159953`}, {2.1999999999999997`, 
     1.3252574989159953`}}], 
    LineBox[{{2.219234615384615, 1.3373712505420023`}, {2.1999999999999997`, 
     1.3373712505420023`}}], 
    LineBox[{{2.219234615384615, 1.3472689062979555`}, {2.1999999999999997`, 
     1.3472689062979555`}}], 
    LineBox[{{2.219234615384615, 1.3556372550017821`}, {2.1999999999999997`, 
     1.3556372550017821`}}], 
    LineBox[{{2.219234615384615, 1.362886248373993}, {2.1999999999999997`, 
     1.362886248373993}}], 
    LineBox[{{2.219234615384615, 1.3692803136799157`}, {2.1999999999999997`, 
     1.3692803136799157`}}], 
    LineBox[{{2.219234615384615, 1.4126287494579977`}, {2.1999999999999997`, 
     1.4126287494579977`}}], 
    LineBox[{{2.219234615384615, 1.4346401568399578`}, {2.1999999999999997`, 
     1.4346401568399578`}}], 
    LineBox[{{2.219234615384615, 1.4502574989159953`}, {2.1999999999999997`, 
     1.4502574989159953`}}], 
    LineBox[{{2.219234615384615, 1.4623712505420023`}, {2.1999999999999997`, 
     1.4623712505420023`}}], 
    LineBox[{{2.219234615384615, 1.4722689062979555`}, {2.1999999999999997`, 
     1.4722689062979555`}}], 
    LineBox[{{2.219234615384615, 1.4806372550017821`}, {2.1999999999999997`, 
     1.4806372550017821`}}], 
    LineBox[{{2.219234615384615, 1.487886248373993}, {2.1999999999999997`, 
     1.487886248373993}}], 
    LineBox[{{2.219234615384615, 1.4942803136799157`}, {2.1999999999999997`, 
     1.4942803136799157`}}], 
    LineBox[{{2.219234615384615, 1.5376287494579977`}, {2.1999999999999997`, 
     1.5376287494579977`}}], 
    LineBox[{{2.219234615384615, 1.5596401568399578`}, {2.1999999999999997`, 
     1.5596401568399578`}}], 
    LineBox[{{2.219234615384615, 1.5752574989159953`}, {2.1999999999999997`, 
     1.5752574989159953`}}], 
    LineBox[{{2.219234615384615, 1.5873712505420023`}, {2.1999999999999997`, 
     1.5873712505420023`}}], 
    LineBox[{{2.219234615384615, 1.5972689062979555`}, {2.1999999999999997`, 
     1.5972689062979555`}}], 
    LineBox[{{2.219234615384615, 1.6056372550017821`}, {2.1999999999999997`, 
     1.6056372550017821`}}], 
    LineBox[{{2.219234615384615, 1.612886248373993}, {2.1999999999999997`, 
     1.612886248373993}}], 
    LineBox[{{2.219234615384615, 1.6192803136799157`}, {2.1999999999999997`, 
     1.6192803136799157`}}], 
    LineBox[{{2.219234615384615, 1.6626287494579977`}, {2.1999999999999997`, 
     1.6626287494579977`}}], 
    LineBox[{{2.219234615384615, 1.6846401568399578`}, {2.1999999999999997`, 
     1.6846401568399578`}}], 
    LineBox[{{2.219234615384615, 1.7002574989159953`}, {2.1999999999999997`, 
     1.7002574989159953`}}], 
    LineBox[{{2.219234615384615, 1.7123712505420023`}, {2.1999999999999997`, 
     1.7123712505420023`}}], 
    LineBox[{{2.219234615384615, 1.7222689062979555`}, {2.1999999999999997`, 
     1.7222689062979555`}}], 
    LineBox[{{2.219234615384615, 1.7306372550017821`}, {2.1999999999999997`, 
     1.7306372550017821`}}], 
    LineBox[{{2.219234615384615, 1.737886248373993}, {2.1999999999999997`, 
     1.737886248373993}}], 
    LineBox[{{2.219234615384615, 1.7442803136799157`}, {2.1999999999999997`, 
     1.7442803136799157`}}], 
    LineBox[{{2.219234615384615, 1.7876287494579977`}, {2.1999999999999997`, 
     1.7876287494579977`}}], 
    LineBox[{{2.219234615384615, 1.8096401568399578`}, {2.1999999999999997`, 
     1.8096401568399578`}}], 
    LineBox[{{2.219234615384615, 1.8252574989159953`}, {2.1999999999999997`, 
     1.8252574989159953`}}], 
    LineBox[{{2.219234615384615, 1.8373712505420023`}, {2.1999999999999997`, 
     1.8373712505420023`}}], 
    LineBox[{{2.219234615384615, 1.8472689062979555`}, {2.1999999999999997`, 
     1.8472689062979555`}}], 
    LineBox[{{2.219234615384615, 1.8556372550017821`}, {2.1999999999999997`, 
     1.8556372550017821`}}], 
    LineBox[{{2.219234615384615, 1.862886248373993}, {2.1999999999999997`, 
     1.862886248373993}}], 
    LineBox[{{2.219234615384615, 1.8692803136799157`}, {2.1999999999999997`, 
     1.8692803136799157`}}], 
    LineBox[{{2.219234615384615, 1.9126287494579977`}, {2.1999999999999997`, 
     1.9126287494579977`}}], 
    LineBox[{{2.219234615384615, 1.9346401568399578`}, {2.1999999999999997`, 
     1.9346401568399578`}}], 
    LineBox[{{2.219234615384615, 1.9502574989159953`}, {2.1999999999999997`, 
     1.9502574989159953`}}], 
    LineBox[{{2.219234615384615, 1.9623712505420023`}, {2.1999999999999997`, 
     1.9623712505420023`}}], 
    LineBox[{{2.219234615384615, 1.9722689062979555`}, {2.1999999999999997`, 
     1.9722689062979555`}}], 
    LineBox[{{2.219234615384615, 1.9806372550017821`}, {2.1999999999999997`, 
     1.9806372550017821`}}], 
    LineBox[{{2.219234615384615, 1.987886248373993}, {2.1999999999999997`, 
     1.987886248373993}}], 
    LineBox[{{2.219234615384615, 1.9942803136799157`}, {2.1999999999999997`, 
     1.9942803136799157`}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.4999999999999996`, 0.}, {3.4999999999999996`, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.467942307692307, 2.204742857142857}, {
     3.499999999999999, 2.3}, {3.5320576923076916`, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.5384692307692305`, 0.}, {3.4999999999999996`, 0.}}], 
    LineBox[{{3.5384692307692305`, 0.125}, {3.4999999999999996`, 0.125}}], 
    LineBox[{{3.5384692307692305`, 0.25}, {3.4999999999999996`, 0.25}}], 
    LineBox[{{3.5384692307692305`, 0.375}, {3.4999999999999996`, 0.375}}], 
    LineBox[{{3.5384692307692305`, 0.5}, {3.4999999999999996`, 0.5}}], 
    LineBox[{{3.5384692307692305`, 0.625}, {3.4999999999999996`, 0.625}}], 
    LineBox[{{3.5384692307692305`, 0.75}, {3.4999999999999996`, 0.75}}], 
    LineBox[{{3.5384692307692305`, 0.875}, {3.4999999999999996`, 0.875}}], 
    LineBox[{{3.5384692307692305`, 1.}, {3.4999999999999996`, 1.}}], 
    LineBox[{{3.5384692307692305`, 1.125}, {3.4999999999999996`, 1.125}}], 
    LineBox[{{3.5384692307692305`, 1.25}, {3.4999999999999996`, 1.25}}], 
    LineBox[{{3.5384692307692305`, 1.375}, {3.4999999999999996`, 1.375}}], 
    LineBox[{{3.5384692307692305`, 1.5}, {3.4999999999999996`, 1.5}}], 
    LineBox[{{3.5384692307692305`, 1.625}, {3.4999999999999996`, 1.625}}], 
    LineBox[{{3.5384692307692305`, 1.75}, {3.4999999999999996`, 1.75}}], 
    LineBox[{{3.5384692307692305`, 1.875}, {3.4999999999999996`, 1.875}}], 
    LineBox[{{3.5384692307692305`, 2.}, {3.4999999999999996`, 2.}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{4.8, 0.}, {4.8, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{4.767942307692308, 2.204742857142857}, {4.8, 2.3}, {
     4.832057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {LineBox[{{4.83846923076923, 0.}, {4.8, 0.}}], 
     LineBox[{{4.83846923076923, 0.5}, {4.8, 0.5}}], 
     LineBox[{{4.83846923076923, 1.}, {4.8, 1.}}], 
     LineBox[{{4.83846923076923, 1.5}, {4.8, 1.5}}], 
     LineBox[{{4.83846923076923, 2.}, {4.8, 2.}}], 
     LineBox[{{4.819234615384615, 0.34657359027997264`}, {4.8, 
      0.34657359027997264`}}], 
     LineBox[{{4.819234615384615, 0.8465735902799727}, {4.8, 
      0.8465735902799727}}], 
     LineBox[{{4.819234615384615, 1.3465735902799727`}, {4.8, 
      1.3465735902799727`}}], 
     LineBox[{{4.819234615384615, 1.8465735902799727`}, {4.8, 
      1.8465735902799727`}}]}, InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "1"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "2"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"Base", " ", "10"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9999999999999998, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LogTicks[0,2]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9999999999999998, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "4"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "8"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"Skipped", " ", "labels"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.1999999999999997`, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"LogTicks", "[", 
            RowBox[{
             RowBox[{"-", "8"}], ",", "8", ","}]}]},
          {
           RowBox[{
            RowBox[{"TickLabelStep", "\[Rule]", "4"}], "]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.1999999999999997`, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507`, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "4"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507`, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507`, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507`, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "8"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507`, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"No", " ", "minor", " ", "ticks"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4999999999999996`, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"LogTicks", "[", 
            RowBox[{
             RowBox[{"-", "8"}], ",", "8", ","}]}]},
          {
           RowBox[{
            RowBox[{"ShowMinorTicks", "\[Rule]", "False"}], ","}]},
          {
           RowBox[{
            RowBox[{"TickLabelStep", "\[Rule]", "4"}], "]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4999999999999996`, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "1"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "2"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "3"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Base", " ", 
         TagBox[
          StyleBox["\<\"e\"\>",
           FontSlant->"Italic"],
          StyleForm[#, FontSlant -> "Italic"]& ]}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.8, -0.3}, {0, 1}, Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LogTicks[E,0,4]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.8, -0.8}, {0, 1}, Automatic, {1, 0}]}},
  AspectRatio->0.5384615384615385,
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->False,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->None,
  ImageSize->{468., 252.},
  PlotRange->{{0.4995, 5.5005}, {-1.5004, 2.5004}},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.526421714609375*^9, 3.526421746296875*^9}},
 CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
 "\tThis tick function was designed on the assumption that you will be \
generating your plots with ",
 StyleBox["logarithmic",
  FontSlant->"Italic"],
 " axes the \[OpenCurlyDoubleQuote]manual\[CloseCurlyDoubleQuote] way.  That \
is, as far as the plotting functions are concerned, you are actually \
generating ",
 StyleBox["linear",
  FontSlant->"Italic"],
 " plots, but you have taken the logarithm of either the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-axis or ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis variable.  Specifically, for base 10,\n\t(1) a ",
 StyleBox["logarithmic",
  FontSlant->"Italic"],
 " (or ",
 StyleBox["linear",
  FontSlant->"Italic"],
 "-",
 StyleBox["log",
  FontSlant->"Italic"],
 ") plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 "), \n\t(2) a ",
 StyleBox["log",
  FontSlant->"Italic"],
 "-",
 StyleBox["linear",
  FontSlant->"Italic"],
 " plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    SuperscriptBox["10", 
     StyleBox["x",
      FontSlant->"Italic"]], ")"}], TraditionalForm]]],
 ", and\n\t(3) a ",
 StyleBox["log",
  FontSlant->"Italic"],
 "-",
 StyleBox["log",
  FontSlant->"Italic"],
 " plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    SuperscriptBox["10", 
     StyleBox["x",
      FontSlant->"Italic"]], ")"}], TraditionalForm]]],
 "\non ordinary linear axes.  A similar procedure holds for bases other than \
10.  Examples of a logarithmic plot and a log-log plot follow."
}], "Text",
 CellChangeTimes->{{3.395151262703125*^9, 3.395151283046875*^9}, {
  3.6141987005863647`*^9, 3.614198723066004*^9}, {3.6141987891789203`*^9, 
  3.6141988224381785`*^9}}],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{
        LinTicks[0,4],
        LogTicks[10,-1,3],
        LinTicks[0,4,ShowTickLabels\[Rule]False],
        LogTicks[10,-1,3,ShowTickLabels\[Rule]False]
        },
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.3951510565625*^9, 3.395151062203125*^9}, 
   3.3951511525625*^9, 3.424727620046875*^9, 3.516134878828125*^9, {
   3.6142024957381134`*^9, 3.6142025125830765`*^9}},
 CellLabel->"In[96]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log10", "[", 
      RowBox[{"Cosh", "[", "x", "]"}], "]"}], ",", 
     RowBox[{"Log10", "[", 
      RowBox[{"Sinh", "[", "x", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LinTicks", "[", 
       RowBox[{"0", ",", "4"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LogTicks", "[", 
       RowBox[{"10", ",", 
        RowBox[{"-", "1"}], ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LinTicks", "[", 
       RowBox[{"0", ",", "4", ",", 
        RowBox[{"ShowTickLabels", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"LogTicks", "[", 
       RowBox[{"10", ",", 
        RowBox[{"-", "1"}], ",", "3", ",", 
        RowBox[{"ShowTickLabels", "\[Rule]", "False"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.51613487109375*^9, {3.6142026308908434`*^9, 
   3.6142026312908664`*^9}},
 CellLabel->"In[170]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdkos31IkCx8ejWVHK2JtHMmNOIs31qLltjcf3VxZl5VBsm7oYGZNnyGul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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALc+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0tN73f7X96/Fj3bEs/G1j+RQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7PYcQHr2de/J3ZKPiiU2j8eD4Qsg6HX
v6A8C6Hj+do/k3BVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8p2u71
w7DUv58Ly4MRReA/mCg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPw3rhIyeK9C/gyXODv/b
4T+idIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPztt5Ory/Me/mAQc
3Mqk4z+KbV2rla3Hv8jJZh6p1uM/UzyrpMcPx78oVPyiZTrkPzOE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D9/QLLSzfezP44QyyqhYPM/7bj8dJegxz9i21S/A8z2P9nT
5If6rdI/ccWEYm8n+j/atDuJKxfZP7FwDFMYSf0/C3Tam1ji3j+he2vqMFcA
QBDf5JKOhOI/gp/8UfTsAUDJ75VMTFnlPwDT4EC8egNAZOozXmYZ6D8mdGZ4
VCoFQGb9/WCbEOs/5PWXVgu9BkC5mPTtCtLtP0rlan2ScQhADNMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DTtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBiddKDIEPY/R+1a9yJVEECnNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPyOwJHIYPo/ZgV14M7OEkAZOHJPA9v7P2Nye7UMmhNA
Rct0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BZvsbMdC4CQOWm
IZSffBhAHMKr5VfcAkCUKBkEuVUZQDxVlDnqmANAwleNNWfMGUAAAAAAAAAE
QOaen5I=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{0., 
      FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
      FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
      FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {3., 
      FormBox["\"3\"", TraditionalForm], {0.01, 0}, {}}, {4., 
      FormBox["\"4\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-1., 
      FormBox[
       TagBox[
        SuperscriptBox["10", 
         RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {0., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {1., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {2., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {3., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {-0.6989700043360189, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.5228787452803376, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.3979400086720377, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.30102999566398136`, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.22184874961635648`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.1549019599857433, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.09691001300805668, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.04575749056067524, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
     0.30102999566398114`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4771212547196624`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6020599913279623`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8450980400142567`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4771212547196626`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-1., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
      FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-0.6989700043360189, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.5228787452803376, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.3979400086720377, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.30102999566398136`, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.22184874961635648`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.1549019599857433, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.09691001300805668, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.04575749056067524, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
     0.30102999566398114`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4771212547196624`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6020599913279623`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8450980400142567`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4771212547196626`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}},
  ImageSize->216,
  Method->{},
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.526421771359375*^9, {3.614202626529594*^9, 3.6142026369541903`*^9}},
 CellLabel->"Out[170]="]
}, Open  ]],

Cell["\<\
Plot[
    {Log10[(10^x)^2],Log10[(10^x)^5]},{x,-1,3},
    PlotRange\[Rule]{{-0.0001,3},{-0.5,4.5}},
    FrameTicks\[Rule]{
        LogTicks[10,0,3],
        LogTicks[10,-1,5],
        None,
        None
        },
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.395151130390625*^9, 3.395151149828125*^9}, {
   3.424727626546875*^9, 3.424727635984375*^9}, 3.516134882390625*^9, {
   3.6142025489981594`*^9, 3.614202549753203*^9}},
 CellLabel->"In[94]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"10", "^", "x"}], ")"}], "^", "2"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"10", "^", "x"}], ")"}], "^", "5"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "4.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LogTicks", "[", 
       RowBox[{"10", ",", "0", ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"LogTicks", "[", 
       RowBox[{"10", ",", 
        RowBox[{"-", "1"}], ",", "5"}], "]"}], ",", "\[IndentingNewLine]", 
      "None", ",", "\[IndentingNewLine]", "None"}], "\[IndentingNewLine]", 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.395151115125*^9, 3.395151116546875*^9}, 
   3.42472766171875*^9},
 CellLabel->"In[410]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt0dsrg3Ecx/HfNuc5Ky7UTEmU5UKyib7fokZJjpfIQkY5pV2h5mLNBWlP
XCAXFMKDwgXFExEJkRYXDlskp4k2p4yx3/P71KfXH/CO1zWX1EoJIcr/e5UQ
744ECrEJntiiNa5xR/ilngpVfp8Fut5V5p7A1zVrEieHmNPCrKwtG6w88NQ1
yBM873OmDdBSj0FeflVuaNlnnkNK+8g6x50wr0E5YR0yWs6Yd7Ar4y3jPxew
Q3XAVY1ZrzLZma+wVNETM55zA4tUFzxapzJKXbfwQH2H/O5Q94HhHvKoX2DM
zTnUpT4x3WDLXM/dXHlm/kLx2Uz03PALFFEJxilsEea3V1BQJUi6Mqq0aieI
yvCw3rAYNegCUR8s5Law0/EGor5oP01X7qs+wEb1x+rJPr+knk8QDUBXfxDo
D77ASQ1EzerAglb+DWqqHBuaApLTatygpwbjfNaoUzbxAzw1BO0Dsdt2qQdE
w5DzqWwvSSDMcAy9XB6TbhFmOJJOY5mmVYKeDq8RKPaWotg7Ev8ALEfo7w==

     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], 
    LineBox[{{-0.1, -0.5}, {-0.026028249030651086`, -0.13014124515325545`}, {
     0.05826757073464903, 0.29133785367324505`}, {0.13692271290300995`, 
     0.6846135645150495}, {0.22218207543361532`, 1.1109103771680766`}, {
     0.3058823930203427, 1.5294119651017135`}, {0.38394203301013086`, 
     1.9197101650506543`}, {0.4686058933621635, 2.3430294668108176`}, {
     0.547629076117257, 2.7381453805862845`}, {0.6332564792345949, 
     3.1662823961729742`}, {0.7173248374080549, 3.586624187040274}, {
     0.7957525179845756, 3.978762589922878}, {0.8807844189233408, 
     4.4039220946167035`}, {0.9000000000000001, 4.5}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  Frame->True,
  FrameTicks->{{{0., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {1., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {2., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {3., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {0.30102999566398114`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4771212547196624`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6020599913279623`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8450980400142567`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4771212547196626`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-1., 
      FormBox[
       TagBox[
        SuperscriptBox["10", 
         RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {0., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {1., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {2., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {3., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {4., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "4"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {5., 
      FormBox[
       TagBox[
        SuperscriptBox["10", "5"], DisplayForm], TraditionalForm], {
      0.01, 0}, {}}, {-0.6989700043360189, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.5228787452803376, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.3979400086720377, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.30102999566398136`, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.22184874961635648`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.1549019599857433, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.09691001300805668, 
      FormBox["\"\"", TraditionalForm], {
      0.005, 0}, {}}, {-0.04575749056067524, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
     0.30102999566398114`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4771212547196624`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6020599913279623`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8450980400142567`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4771212547196626`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.3010299956639813`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4771212547196626`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6989700043360187`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.7781512503836434`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.9030899869919433`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.9542425094393248`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.301029995663981, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.477121254719663, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.6020599913279625`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.698970004336019, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.778151250383644, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.845098040014257, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.903089986991944, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.954242509439325, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, None, None},
  ImageSize->216,
  PlotRange->{{-0.0001, 3}, {-0.5, 4.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39515095228125*^9, 3.39515112225*^9, 
  3.424727663390625*^9},
 CellLabel->"Out[410]="]
}, Open  ]],

Cell[TextData[{
 "If, instead, you wish to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions directly for your logarithmic plots, see the discussion below, \
under \[OpenCurlyDoubleQuote]Use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and related functions\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{{3.614200948498361*^9, 3.614201004088439*^9}, {
  3.6142014869491153`*^9, 3.614201493389124*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Automatic ticks for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot functions"
}], "Subsubsection",
 CellChangeTimes->{{3.424727272421875*^9, 3.42472727859375*^9}, {
  3.424730401296875*^9, 3.424730407609375*^9}}],

Cell[TextData[{
 "\tThe functions ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " can also be specified as automatic tick generation functions for the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plotting functions.  This saves you typing the plot range explicitly each \
time, at least if you do not wish to specify details such as the number of \
subdivisions."
}], "Text",
 CellChangeTimes->{{3.42472768440625*^9, 3.424727776*^9}, {
  3.42473041434375*^9, 3.4247304185625*^9}}],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{LinTicks,LogTicks,None,None},
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.3951510565625*^9, 3.395151062203125*^9}, 
   3.3951511525625*^9, 3.424727620046875*^9, {3.42472778403125*^9, 
   3.424727807609375*^9}, 3.516134894953125*^9, {3.6142025576386538`*^9, 
   3.6142025582076864`*^9}},
 CellLabel->"In[96]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Cosh", "[", "x", "]"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Sinh", "[", "x", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"LinTicks", ",", "LogTicks", ",", "None", ",", "None"}], "}"}]}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9},
 CellLabel->"In[411]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdkok71AkDx8fRrKPI2A2RGfMkwjpq3rZc319ZbFYewtaqxciYnEmupWNJ
W15epImR29redUSW9LBoJOWmhsixRoOcuSaWUd7d9/M8n+fzD3y0vC6cZEmS
SCSfv/2n2Ve9yCbeCZYbybfOBflKWzzj0+xP0XzhR/1+dpHeaLn1vOE6jfYj
amSmp/PoY5YKqdUP5QZiIX2naXe3zYplNu8/1G20eBRO3gz0oUvAYME7aYud
DCtNm+zMZjmMKOR82uxPRdzPD7Ov2Chj733ZQxviu5g2yGeame9GgEVY4Bo1
A2UHHK22tLRQ2SsoFFll4bPv6+/8WaaNDX/74SV2Lm5NTpKrn+khT2I4fs06
H2KNlNInJsb4uvO29mp/AZbERt0Z1gcxxbVtFPkWIppskj+RfQiJ3h/Proh/
RXicj3SuqSn44vOcRWoR0v8imRTSjiL8habxQkUxPtR/a5nuaoXdd3rb561K
8VduJONxqTW89AipWXY58tW4RiGNdpAUR3WLLj+E+ZTTKvnaCfQKXPeIrCvQ
HNb5ubuRIyJL5WuW+3/HA93lF+bHnGGXOklezquEoJiuYTHhAo3IRpcl3yq0
C3Zo2GR8B55VxOKC+BHU6y0qfBlu+Gzorc48tQZH/UsGzqgzMcCrD5ubqoGq
janpqLEXiu9zm2YravHq5ckfRxzOwSHEwWPGqg5vDrAp1oUspMnWpr1jP0FE
sZc8t8oPVRF2IZdUeeAvPBC37ghA1sxXaiuXedBwqG/xuxCIoB4Ke9m6ETIK
hXvWtYNByWqRXOp/CuNTnZwVxiWIFaqLgs2b8JUKN9xIKhTjMb84LuY1wVnD
Nz6zLxTV7Ks5C77P8Hu7ji3pZjjcDjJM34ubkRuVZjqqHoX8ttyLs9RW7K/I
oV0lx0DEfaQ3mtiKKc7DxMB7MbBhtwtfrbfiywFlzxbjWMxJrbnW8tvgvz9P
VOd9HYctHEzjb3bgTZes8b+nb6CnfFNSZ6Eblu/xfp6VAApk3XcY9iA4mbVb
n5YIs30c05vePThhTjnQPJyIJFHRStTLHrzInqZu/yEJjNt9LK+Sl2ArMqnj
dSm41mZgZ+LBx5cRl2JuKHHwW8XjfSV3+Xg3GutnH8PBK+4xKe0OPl63Hdp3
ZJmDvezTdapHelFKV+TF9N9Fm1ScIUm5D2+33ggbytOxy2KI0v38NZ4E2Zzw
TMtEWXn8UIDhIIoTR+sE6gWYocwk2jEHkSaxHpDnWQCdcDtLXc4glmX3G/T/
WoA8c/l84fogChvcy38z+QWprYk+bs1DOL3YkMV3KES4MHnJ9uwImhkxj8m5
95Er335dyVoAgX/MAo9TAkuL6LM/uQsw3umb0fmuBMNB+v9aiBDA8p1egq1Z
KVRfJUx2FAuQUez0KUZYittc++O3do5BqfxbusyRMlzX7lLYGhrDKt3JT+bv
z9l4mTEXIsSC7QwxzqwEqWC1dihBiL2u7DubKZXgSmsMtxUKcV5S0eNrXiVa
Wn00i14LsdR4j8ekVkHXZbOAZToOCNOPdY9WYeq8TumfEhMI9NQYd/Kthl/q
lYaelElYGPi7DGbXIGhiv7CqbBrBB01ylI/xIKcVpzN6eBF/iNU3DKpakLSz
XS/fcwV3PVmRDk974DXk8kSqYxWKtYQ9a7IPF5vjvC7obMDtm58bKxlDqAje
7qx6/CPO8In/GukKkB/tP2N8ikSoUY+7Hd18i9jcTSfRnASRHEju7i2aAIkv
IOqipAhuaCNd0nEK+0J9Il30thFj1xYVLzBmMf4h/Tv5ejIhkU87fXhmHnYT
fldSL8oQ14JvXDQMWoTDeIq+pqYc8UJ7LmLn2BJmmrx+ankgTxSE0kkeZisw
VHq9x8pjB6HGCnhgWymCHD4wh1cUiEslKjmulFXYzrut0V13EvpVbNeRpDUM
PPWWcDNQIqID+vuSpNfx6NYzd9oHJcJ0MZtpxtyAz7YwQVcXhVD5NH7GYUiM
cyHRj7bfUyaCyhl7nc0/woit32XP/Jyg055rB6Z9QjfFQD7syBeEbaa/sohM
Iv4oi800kNpFbM9kdulUk4hoCT3HjpFdhPZJboB8qAQhNxz1TVCVCuHc+lEu
0lCSmLivxcm9rEqo7jqk4jYsSXB01aRrXNWIrFiFolmuFBHICB9ldagRpP8j
TfwPYsMCkw==
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALM+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0pN73f7X96/Fj3bEs/G1j+PQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7LYcQHr2de/J3ZKPiiU2j8dD4Qsg6HX
v6A8C6Hj+do/knBVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8o2u71
w7DUv58Ly4MRReA/mCg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPwzrhIyeK9C/gyXODv/b
4T+hdIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPzpt5Ory/Me/mAQc
3Mqk4z+JbV2rla3Hv8jJZh6p1uM/UjyrpMcPx78oVPyiZTrkPzKE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D9+QLLSzfezP44QyyqhYPM/6rj8dJegxz9i21S/A8z2P9jT
5If6rdI/ccWEYm8n+j/ZtDuJKxfZP7FwDFMYSf0/CXTam1ji3j+he2vqMFcA
QA/f5JKOhOI/gp/8UfTsAUDI75VMTFnlPwDT4EC8egNAY+ozXmYZ6D8mdGZ4
VCoFQGX9/WCbEOs/5PWXVgu9BkC4mPTtCtLtP0rlan2ScQhADNMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DTtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBeddKDIEPY/R+1a9yJVEECmNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPuOwJHIYPo/ZgV14M7OEkAYOHJPA9v7P2Nye7UMmhNA
RMt0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BZvsbMdC4CQOWm
IZSffBhAG8Kr5VfcAkCUKBkEuVUZQDtVlDnqmANAwleNNWfMGUAAAAAAAAAE
QKtWn3A=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  Frame->True,
  FrameTicks->
   FrontEndValueCache[{
    CustomTicks`LinTicks, CustomTicks`LogTicks, None, None}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0.}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, None, None}],
  ImageSize->216,
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.42472781853125*^9},
 CellLabel->"Out[411]="]
}, Open  ]],

Cell[TextData[{
 "\tWhat if you wish to have tick marks on the top and right as well, but \
without labels on them?  Simply specifying ",
 StyleBox["FrameTicks\[Rule]{LinTicks,LogTicks}",
  FontFamily->"Courier New"],
 " or ",
 StyleBox["FrameTicks\[Rule]{LinTicks,LogTicks,LinTicks,LogTicks}",
  FontFamily->"Courier New"],
 " would unfortunately result in ticks with unsightly and redundant labels.  \
This can be avoided with the CustomTicks ",
 StyleBox["StripTickLabels",
  FontFamily->"Courier New"],
 " function, as shown below."
}], "Text",
 CellChangeTimes->{{3.4247296204375*^9, 3.424729741734375*^9}, {
  3.424729775875*^9, 3.424729877875*^9}, {3.4247302263125*^9, 
  3.42473023909375*^9}}],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{LinTicks,LogTicks,StripTickLabels[LinTicks],\
StripTickLabels[LogTicks]},
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.4247314673125*^9, 
   3.424731485171875*^9}, 3.516134901390625*^9, {3.614202565856124*^9, 
   3.6142025663111496`*^9}},
 CellLabel->"In[189]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Cosh", "[", "x", "]"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Sinh", "[", "x", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"LinTicks", ",", "LogTicks", ",", 
      RowBox[{"StripTickLabels", "[", "LinTicks", "]"}], ",", 
      RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}},
 CellLabel->"In[189]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdkok71AkDx8fRrKPI2A2RGfMkwjpq3rZc319ZbFYewtaqxciYnEmupWNJ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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALM+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0pN73f7X96/Fj3bEs/G1j+PQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7LYcQHr2de/J3ZKPiiU2j8dD4Qsg6HX
v6A8C6Hj+do/knBVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8o2u71
w7DUv58Ly4MRReA/mCg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPwzrhIyeK9C/gyXODv/b
4T+hdIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPzpt5Ory/Me/mAQc
3Mqk4z+JbV2rla3Hv8jJZh6p1uM/UjyrpMcPx78oVPyiZTrkPzKE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D9+QLLSzfezP44QyyqhYPM/6rj8dJegxz9i21S/A8z2P9jT
5If6rdI/ccWEYm8n+j/ZtDuJKxfZP7FwDFMYSf0/CXTam1ji3j+he2vqMFcA
QA/f5JKOhOI/gp/8UfTsAUDI75VMTFnlPwDT4EC8egNAY+ozXmYZ6D8mdGZ4
VCoFQGX9/WCbEOs/5PWXVgu9BkC4mPTtCtLtP0rlan2ScQhADNMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DTtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBeddKDIEPY/R+1a9yJVEECmNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPuOwJHIYPo/ZgV14M7OEkAYOHJPA9v7P2Nye7UMmhNA
RMt0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BZvsbMdC4CQOWm
IZSffBhAG8Kr5VfcAkCUKBkEuVUZQDtVlDnqmANAwleNNWfMGUAAAAAAAAAE
QKtWn3A=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  Frame->True,
  FrameTicks->FrontEndValueCache[{CustomTicks`LinTicks, CustomTicks`LogTicks, 
     Composition[CustomTicks`StripTickLabels, CustomTicks`LinTicks], 
     Composition[CustomTicks`StripTickLabels, CustomTicks`LogTicks]}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0.}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {0.01, 
       0.}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 
       0.}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {0.005, 
       0.}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}}],
  ImageSize->216,
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.424729699078125*^9, {3.42472975165625*^9, 3.424729769453125*^9}, 
   3.42472988265625*^9},
 CellLabel->"Out[189]="]
}, Open  ]],

Cell[TextData[{
 "If you are doing many such plots, it is easiest to set the necessary \
options as the default options for ",
 StyleBox["Plot",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.424729999703125*^9, 3.4247300188125*^9}, {
  3.4247302100625*^9, 3.42473021253125*^9}}],

Cell["\<\
SetOptions[Plot,Axes\[Rule]False,Frame\[Rule]True,FrameTicks\[Rule]{LinTicks,\
LogTicks,StripTickLabels[LinTicks],StripTickLabels[LogTicks]}];
GraphicsGrid[{{Plot[Log10[x^2],{x,0,10}],Plot[Log10[x^-2],{x,0,10}]}}]\
\>", "Program",
 CellChangeTimes->{{3.424729960359375*^9, 3.424729964*^9}, {
   3.42473003846875*^9, 3.424730186328125*^9}, {3.424730256921875*^9, 
   3.424730320734375*^9}, {3.424731562421875*^9, 3.42473160075*^9}, 
   3.5161349083125*^9, {3.6142025699743595`*^9, 3.6142025705483923`*^9}},
 CellLabel->"In[206]:="],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Plot", ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"LinTicks", ",", "LogTicks", ",", 
       RowBox[{"StripTickLabels", "[", "LinTicks", "]"}], ",", 
       RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"x", "^", "2"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"x", "^", 
          RowBox[{"-", "2"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}], "}"}], "}"}], 
  "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.424729960359375*^9, 3.424729964*^9}, {
  3.42473003846875*^9, 3.424730186328125*^9}, {3.424730256921875*^9, 
  3.424730260734375*^9}, {3.4247303266875*^9, 3.42473032909375*^9}},
 CellLabel->"In[210]:="],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVznk8FPgfBnBMtf3oMLQqcl+htLXZQny+SylHKppcu8o4JtXaLqTpENVQ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Times"},
      Frame->True,
      FrameTicks->
       FrontEndValueCache[{CustomTicks`LinTicks, CustomTicks`LogTicks, 
         Composition[CustomTicks`StripTickLabels, CustomTicks`LinTicks], 
         Composition[
         CustomTicks`StripTickLabels, CustomTicks`LogTicks]}, {{{0., 
           FormBox["\" 0\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\" 2\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
           FormBox["\" 4\"", TraditionalForm], {0.01, 0.}, {}}, {6., 
           FormBox["\" 6\"", TraditionalForm], {0.01, 0.}, {}}, {8., 
           FormBox["\" 8\"", TraditionalForm], {0.01, 0.}, {}}, {10., 
           FormBox["\"10\"", TraditionalForm], {0.01, 0.}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]], DisplayForm], TraditionalForm], {0.01, 
           0.}, {}}, {-1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {0.01, 
           0.}, {}}, {0., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {3., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.4771212547196626`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.6020599913279625`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.845098040014257, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {6., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {8., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {10., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {-1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.01, 
           0.}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.4771212547196626`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.6020599913279625`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.845098040014257, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          2.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}}],
      ImageSize->216,
      PlotRange->{{0, 10}, {-1.4104117472020163`, 1.9999999822736942`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {115.2, -70.08505432423807}, 
     ImageScaled[{0.5, 0.5}], {216, 133.49534156997728`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Xk4FGobBnBM9fXRYuhIdrKEmk6dfIp43mizpFJT4hwy9upzUiFNSSlD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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Times"},
      Frame->True,
      FrameTicks->
       FrontEndValueCache[{CustomTicks`LinTicks, CustomTicks`LogTicks, 
         Composition[CustomTicks`StripTickLabels, CustomTicks`LinTicks], 
         Composition[
         CustomTicks`StripTickLabels, CustomTicks`LogTicks]}, {{{0., 
           FormBox["\" 0\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\" 2\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
           FormBox["\" 4\"", TraditionalForm], {0.01, 0.}, {}}, {6., 
           FormBox["\" 6\"", TraditionalForm], {0.01, 0.}, {}}, {8., 
           FormBox["\" 8\"", TraditionalForm], {0.01, 0.}, {}}, {10., 
           FormBox["\"10\"", TraditionalForm], {0.01, 0.}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-3., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]], DisplayForm], TraditionalForm], {0.01, 
           0.}, {}}, {-2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]], DisplayForm], TraditionalForm], {0.01, 
           0.}, {}}, {-1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {0.01, 
           0.}, {}}, {0., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {0.01,
            0.}, {}}, {-2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.5228787452803374`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.3979400086720375`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.154901959985743, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {6., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {8., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {10., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{-3., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {-2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {-1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 
           0.}, {}}, {-2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.5228787452803374`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.3979400086720375`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.154901959985743, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-2.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {0.005, 
           0.}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}}],
      ImageSize->216,
      PlotRange->{{0, 10}, {-1.9999999822736942`, 1.2035447261209202`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {345.6, -70.08505432423807}, 
     ImageScaled[{0.5, 0.5}], {216, 133.49534156997728`}]}, {}},
  ContentSelectable->True,
  ImageSize->{472.8, 152.17010864847614`},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.424730089890625*^9, 3.424730101328125*^9}, {
   3.42473014025*^9, 3.42473018709375*^9}, 3.424730261890625*^9, 
   3.4247303296875*^9},
 CellLabel->"Out[211]="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<LogPlot\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<False\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Controls whether \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
      "\"\<operates as it should for standalone use or for automatic tick \
mark generation with Mathematica's \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LogPlot\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
     "\"\< special option.\>\""}], "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.516135363625*^9, 3.516135492234375*^9}, {
  3.5161355373125*^9, 3.516135567359375*^9}},
 Hyphenation->False,
 CellLabel->"In[17]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["LogPlot",
        FontFamily->"Courier"], 
       StyleBox["False",
        FontFamily->"Courier"], 
       RowBox[{"Controls", " ", "whether", " ", 
        StyleBox["LogTicks",
         FontFamily->"Courier"], "operates", " ", "as", " ", "it", " ", 
        "should", " ", "for", " ", "standalone", " ", "use", " ", "or", " ", 
        "for", " ", "automatic", " ", "tick", " ", "mark", " ", "generation", 
        " ", "with", " ", 
        RowBox[{"Mathematica", "'"}], "s", " ", 
        StyleBox["LogPlot",
         FontFamily->"Courier"]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.51613557096875*^9}],

Cell[TextData[{
 StyleBox["LogTicks",
  FontFamily->"Courier"],
 " special option."
}], "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.516135571015625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and related functions"
}], "Subsubsection",
 CellChangeTimes->{3.61420151898416*^9}],

Cell[TextData[{
 "\tIf you wish to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions directly for your logarithmic plots, you may also do so.  \
However, ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must then be instructed to adjust its output accordingly.  (",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " expects tick coordinates to be specified as the true coordinate value, not \
the logarithm of the coordinate value.  ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must also interpret its ",
 StyleBox["n1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["n2",
  FontSlant->"Italic"],
 " arguments differently in this case.)  Automatic use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " can be accomplished by setting the option ",
 StyleBox["LogPlot->True",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.424729999703125*^9, 3.4247300188125*^9}, {
   3.4247302100625*^9, 3.42473021253125*^9}, {3.51613501165625*^9, 
   3.5161352076875*^9}, {3.516135591578125*^9, 3.516135662328125*^9}, {
   3.51613603228125*^9, 3.516136032703125*^9}, {3.5161361073125*^9, 
   3.516136130953125*^9}, 3.6142015257491693`*^9}],

Cell["\<\
SetOptions[LogTicks, LogPlot -> True];
Plot[
 {Cosh[x], Sinh[x]}, {x, 0, 10},
 PlotRange -> {{-0.0001, 4}, {10^-0.5, 10^2.5}},
 FrameTicks -> {LinTicks, LogTicks, StripTickLabels[LinTicks], \
StripTickLabels[LogTicks]},
 Frame -> True, ImageSize -> 72*3
 ]\
\>", "Program",
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.51613517521875*^9, 
   3.51613523584375*^9}, 3.51613532775*^9, 3.516135954515625*^9},
 CellLabel->"In[7]:="],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"LogTicks", ",", 
    RowBox[{"LogPlot", "->", "True"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cosh", "[", "x", "]"}], ",", 
     RowBox[{"Sinh", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "0.5"}]}], ",", 
        RowBox[{"10", "^", "2.5"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"LinTicks", ",", "LogTicks", ",", 
      RowBox[{"StripTickLabels", "[", "LinTicks", "]"}], ",", 
      RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.51613517521875*^9, 
   3.51613523584375*^9}, {3.516135863421875*^9, 3.51613593571875*^9}},
 CellLabel->"In[171]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk2k41Hsfh+1mBvOPtIy1bJWGpKzJ91cqUpEtJzQRZalTREWyFaXMlHPS
2LcMhWOZmhnZImv2/REjhIQsLTSW8Jzzua77ul/erz7bL1yzvijAx8cX9y//
2fziREfl5A3jH+v/bcZIyETGe4hkCyt2PkIfULbxvtS4pNckN+jXinrhgRqM
x+RUwm6pXYU7/xTLmnsMGJ9o6X2VTPKDeHJJMhlNGqtQ5TPXFQPAQrbVbkvJ
T+Pf5q6xLmrBYLBPWUfa47fxVHh3jQs9DCb/NksUthMEezde+d+kcBgVIaqv
Ah5qTGSKqpPuw8hlLGluHgMt5YOF84oPQQWs22aKN0KSgHO2akYUBJ17yT0/
uAVwI3efn1F7DOkrI9tb3OWgZLizpdo2GqjCARSZ3G3gfdrN3In+FwzcnO1r
tFWGj3semNBIMaCh9J2TCrsgJnVrparjMxiPrZ2pCiWDOZZj9DaJDv5RW4Kc
5/cAZ7ZZZ04xHkhpGt/vFe+DKxTKqwcuCSAlLqiIq9ABpdY5zW0ZiUBraF+r
/6gHj/OkdlqppUCqg7vy0iUjOCrPYEy6p0LKqMU9zw5jCK5L2PDONg0EAzif
H+Yg2K9Lpp2lpwNPaQlPsDWBtE2W9x+RGKBdv6jrYHwcAltia86UMIDaQqRd
/2AOZyKGBZQdM6GN7EdXDTkJ4gs+IaVJWTCHL/V1+GEJ/t0x/tOK2VCi0dO+
XGQDNtSPnDeV2ZBsFPrrSpEtaB5RWwh3yQG/wUMiu8vtYOx1kY98Ri743WiV
fsS1B6un/V4Wavlw6X3wWourE5BPKGfL1OfD5MUftPhn5wAneOXLuHsBbKbj
jhe0UOB88RqzwrYQknpqVJ1eOsOmXdGaf9CZ8JM/oULOyhXCcK93PCSx4MsR
xSMUA09QN/0r8pU3C9yP/TlauckLOiOuTXLrWUBja27rWvACFUFyruZNNgx/
qngu/O4K1K0yNLs7OUA03xTQesgbxH/SdRSpxVAuzaUznfyAvfcG3Wy0GHRS
LrZZT/gBxduG52NYAqJ1LNHGGzegYAYrrpkoAfMn5xcM6DfBeiLSyOtoGZiR
iApyM/4Q9/G2CXvtLejSPDc1/QiCQ3JnGYN2FVCAmyeXJQbDlIOeMC6vAj7K
FYqFHQsBhekA1zyNSoh5vPtd1elQuOapq8o3UAnDOUGBJZwwkHIreJmpXwVX
uZeH3fLD4Y+z6QXfvteAl943QcLJKJjj2hKey9QCt9r0lygnCu5TcBdtTGqh
Y76O0raNCq9dr8lwYmoh0GOjcckiFYhXD0YE6tWBzlri8CrzMdTe7XMQCaoH
Oe3c99Kqf4H2P5IicrhGGP3e/Fsf9wwaNGudW7QaoVdmJb74+DNwZvqXBp9t
hLLchODkqGdA4wx5f8ppBAGW0NfHG+gwUZnHzTrVBP2j1PHNirGQ0nOcufdp
M2xoiBoqsIgHsfUwJ1OFNvDjPRfP4iVDnKc9hXysDUYe+HBnTFJApZvsLHm1
DYING/58Gp0Cxtm9rtzyNihtG2Xw1FOhOJvOLtJsh3LiZg9J7TSYsZkuO9Ha
Dh2WnKoV33Swexnb5CvRCXTTSUq8DANUrWYnqqO6gV2bcebw92yQCTE1dE/v
hiLVdA5pRw5syEuLIhR1g5++xKzquRxYxtloWo10w9YmGmegIQfaK4t8B/V7
gP8i17cqMxdua4WtLX7uAcPgO0w39zxoxaSlNVEvcInHaX2RhXCr1QDi5vtg
QqnjxVQIC4ia7M8NuH7QITS74FJZwKBpUVfk+uF6U1bLgbcs6Di5o49ytB8G
PnVnjv5mwe4maV9Vej8UiQVX6wayYah+LuuVHhfs09+IjgdywPRdJrHl9gCs
W0RyD9PewBaW5CA//xAU21VJV86WAWfEpLnNaATE6+9kOFVWQ5VXsuzZ6TFw
LSt070xsgAW1g1jen1/gdJCB+6GUNhBYyt0gqzoFaR9EXE6e6QLddWeOTf40
iGZ3PBng/g+aw/e31qnPAT1lT1VmaD8oRn9dyp79Bg75+9VvZQ7CV97QYI/W
D+gqVxAbtvsEjKnSRuLjn0B61e4WFzsKRPkXc2Nj8+DZeJ3cPvQZqJ7sS2kq
v6DH8cu9cYkJ+IVyxzxCeFA0I4AV35oCP+0a1ubqRbBzPPolumoahvJrojq2
LwNr0ESfz2wOVry6E3fdXoHFMkO71bFvsPuQ6Nql0t+Qpb74M3njDzB9vt2d
uWUNtoY6ODMpP+GW/HmlT07rcCwGZe+lzwN52k6s9xQfWnyqURHcsAAbsW+4
mmU+NIDfmcDeygOhisQC5SR+RCfpc/htFuHy/tI+/AkBhF+yB6HsJcg9fiHt
7S8BdODCa4dfS8uw8FVmwzhdEFXwDdxW0vkNbBtTwZgjQijy1j7nd1GrEGIW
kcoaF0Iybr05qHkNtn80/5ARIYwmJ8bU7gjyIUO98BiStgjaqfxEJyifDzkp
tC3xd4mgt3xbVg5a8KOFRtqId5gokjvHTE1a4UdxQhQ/axUccpNKCMlKFkAb
B9nPBWpwSCNkmJduJIiEg8JsDXzwaLF7gLd3UhDxZVMKRqQI6F67tbb9IyF0
PaGAJlVFQF4CiCphIIzKd0fiJK+KobsKpZYvxoSRpPl18l2iOFo75vj0fbgI
GtBo7wooE0fRMm8ZN7VFUeG/Fx2jSCD/Ap+crG5RdK5AV1J+TQIthwZW5Pvi
UGhEethADhF5G5bJHdqGR3kT8onEkxhSdPUPtHyHR5HJEc6DFhjSrqnKU6jB
IzfrGdV8KwwxKH7DM3V4JFdWVnjKHkPGCuKm1GY8evTEsY56AUPUSWFSQy8e
eejGfycEYOjy+bG2w7N4pBQubSaahaF+R7cHurIEtKZ/R6L3JYbiL0nUCSsQ
UN/MaGdWLoYSV6WFe7YRULT963PHmBiyrTcO91UjoHV1a9+IMgxtjVm4X7iX
gAY6nqQIdmEoY5WTrG5GQG/u81y7ejCkK6s+smROQDEHzu/K+IAhfzZPreEU
AZ3I1GQdHsSQzYV0prsNAZX4tzSETWJItmhHE4NCQHQNnSdW0xjK7HSX8nMh
IJ+RJNvtcxia9eVzMHEjoJ0nrwxVzmPooaXh1CdPAhLi72ZE8zCkSeRqM68Q
0DD7gJfz8r99x67A0GsEVOaVsUdrFUN6S0q1ltcJKFZRbGF9HUNzOQ1ExRsE
9H9vwHVn
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkWs0lAkYgM0YxnwuX2S3o1x2LOVSshWi9L7VonI5EbGb5Kgkl0psllPJ
rkuF1W4iKUskcotcKvLZKEfr2rg0GgaRZBiTyzBqZtsfz3l+P+dh+512O06X
k5Pb/5X/XS3xUkkVceAbj6ra8qBPlKHr9IfGxG7wck/Q7x0XUaujHWxO5HQD
3+hWW2iviFpRkp1I1HRDye6CSN0XIkqidMDMdaQbhNejdj24K6I6G2rCBrf2
AI8lKkvwEVFR5jHSxbEeuOpV+N127gzVTmpqmmEfPOuQTvk+ElIR7dZwc44L
t/o7iFmagFIzqxprUeoH/sSuxbrxSSov2TxpWbsfqpoD9TLaJqkup3VcH7t+
KDA9lpeQMUmZ/qsZZpjWD9KJez/bbJqk+M3C/AqrtxCxUYs34P+Rcvjnnlpb
FA/4ufSWY7wP1KpK9UEajQ+mF+gt3rNjVPXI7taO7SMwHiC2tXAYop4H3lnz
k2AUfKIYqaLyXmp+rS1ZEjIO8lMFN5qLWin6UtGKNYYfoS1AelzwtoaylPlW
HygVAPCOdCZH3oDW2C3tL02EUKCZslK0swH0rk0uFU7PgB+vouuJSztMivmD
PeafwOyCa3BIWA/kfax9pfbHLLCjGup9VHigpnNfODo6B8FrTb9ITIYh6WSV
f7bBAlhY2bvUMEdhAYtGA6LF8Pox2/ugxjiEb2qq/LZxEXJrtovO8SaAX9qU
2MWWQL+HgS2nVwDLgd2ZxlHLkM+csMt5IgTTnUypf+1nSHNNiOj8QQQOd9kn
yldJoceXcdMq+xNE6BzRH/aWwWuuNbN8dhbWCzyU+5zlsGLstx3BO+ZhJTmj
1CSRw/jGtCXIXQAGlVn2/W0aijWcG4qnxRC0pZbLcqRj3y/5R8+4L0HRXr/s
+gU63vYs3hZaIYH5ydUr3qfJo3AA3BbFy1B1wEE+9UcG/nU6ltD3+gLRe+L+
rnzPQOMg5Yvm2VJgD+x7kxungDoZj3pth2VgYxWbqrVJEanh3b8nZcmht27H
Eo2jiFfexRRnIQ3nXyWPnIlhYuszerzeDA1vMnzC3QyU8H56+AT3Oh1XDlbd
pTcpYX1reSZskUeFCzHu1qEs9FSsztYZkUe5Qp+yEQ0C66KvXHaMZeDZW2XJ
Gs8JdOsQw/xmBXxmellJ/ZQymuw/VeI1pIDq+86u/01NBfXdUrhaMYrI29DJ
iaxTwYxRI8tDG5n4MAsMRn1UcazH7b2si4mHyyzVdaSq2G4DT0+GKuGluJwY
3gM1ZDvn7D2oy8KSDzqZak4kmtp1GBZTLLx8J8530IXE9ONnL55/zsJjblOG
pa4khuuX9jq9YKF2Xd1DZ08Se6/PxE29YuHVlEMvk/xIdLQp5Jv1sjDAMkNE
RJK4X8voUrmAhfqxmnuY+SRmqNhHVGsRKN16XrWvgMShwrjGeG0CuVPvXucX
kRid7k966hF4zfPRYftyEnNDVPPFBgTKTNzC4upIPIoL7VvNCeR1pWTJc0iU
1IeQtfYEPo4XH+X0kDhgPOyRuJfA1G1HjHPfkJgvXso85ESg4z2zyl2DJHo9
1V732ZXAp7+2tcRMfO1p3mBte5jAtA0WKa4CEj9bcM6r+hIYOnLbnS0ksV6m
1zDgR6CRUzC/YY7EvjsP7S4GEMigdeddE5O4eXouwSWIwKGqbYG+EhI5fw63
6J76+jEwd6P5FxKdX55TFp4hMF1PeV4mI5HVUulEhRH4H4OLa38=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.0001, -1.1512925464970227`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->FrontEndValueCache[{{{{-2.3025850929940455`, 
        FormBox[
         TagBox[
          SuperscriptBox["10", 
           RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
        0.01, 0}, {}}, {0., 
        FormBox[
         TagBox[
          SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
        0.01, 0}, {}}, {2.302585092994046, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
        0.01, 0}, {}}, {4.605170185988092, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
        0.01, 0}, {}}, {6.907755278982137, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
        0.01, 0}, {}}, {-1.6094379124341005`, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-1.2039728043259361`, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.9162907318741553, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.6931471805599457, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.5108256237659909, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.3566749439387326, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.2231435513142104, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.10536051565782652`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       0.6931471805599452, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.0986122886681096`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.3862943611198904`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6094379124341, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.7917594692280547`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.945910149055313, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       2.0794415416798353`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.197224577336219, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       2.9957322735539913`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       3.4011973816621555`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       4.2484952420493585`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.382026634673881, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.499809670330265, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.298317366548037, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.703782474656202, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.991464547107983, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.396929655216145, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.551080335043405, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.684611727667927, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.802394763324311, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}}, {{-2.3025850929940455`, 
        FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
        FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2.302585092994046, 
        FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4.605170185988092, 
        FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {6.907755278982137, 
        FormBox["\"\"", TraditionalForm], {
        0.01, 0}, {}}, {-1.6094379124341005`, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-1.2039728043259361`, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.9162907318741553, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.6931471805599457, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.5108256237659909, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.3566749439387326, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.2231435513142104, 
        FormBox["\"\"", TraditionalForm], {
        0.005, 0}, {}}, {-0.10536051565782652`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       0.6931471805599452, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.0986122886681096`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.3862943611198904`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6094379124341, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       1.7917594692280547`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.945910149055313, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       2.0794415416798353`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.197224577336219, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       2.9957322735539913`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       3.4011973816621555`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
       4.2484952420493585`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.382026634673881, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.499809670330265, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.298317366548037, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.703782474656202, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.991464547107983, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.396929655216145, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.551080335043405, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.684611727667927, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.802394763324311, 
        FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {
     CustomTicks`LinTicks, 
      Composition[
      CustomTicks`StripTickLabels, 
       CustomTicks`LinTicks]}}, {{{{-2.3025850929940455`, 
        FormBox[
         TagBox[
          SuperscriptBox["10", 
           RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {0.01, 
        0.}, {}}, {0., 
        FormBox[
         TagBox[
          SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {0.01, 
        0.}, {}}, {2.302585092994046, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {0.01, 
        0.}, {}}, {4.605170185988092, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {0.01, 
        0.}, {}}, {6.907755278982137, 
        FormBox[
         TagBox[
          SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {0.01, 
        0.}, {}}, {-1.6094379124341005`, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-1.2039728043259361`, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.9162907318741553, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.6931471805599457, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.5108256237659909, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.3566749439387326, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.2231435513142104, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.10536051565782652`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       0.6931471805599452, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.0986122886681096`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.3862943611198904`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6094379124341, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.7917594692280547`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.945910149055313, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.0794415416798353`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.197224577336219, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.9957322735539913`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.4011973816621555`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.2484952420493585`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.382026634673881, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.499809670330265, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.298317366548037, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.703782474656202, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.991464547107983, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.396929655216145, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.551080335043405, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.684611727667927, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.802394763324311, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}}, {{-2.3025850929940455`, 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2.302585092994046, 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {4.605170185988092, 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {6.907755278982137, 
        FormBox["\"\"", TraditionalForm], {0.01, 
        0.}, {}}, {-1.6094379124341005`, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-1.2039728043259361`, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.9162907318741553, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.6931471805599457, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.5108256237659909, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.3566749439387326, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.2231435513142104, 
        FormBox["\"\"", TraditionalForm], {0.005, 
        0.}, {}}, {-0.10536051565782652`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       0.6931471805599452, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.0986122886681096`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.3862943611198904`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6094379124341, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.7917594692280547`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       1.945910149055313, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.0794415416798353`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.197224577336219, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       2.9957322735539913`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.4011973816621555`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.2484952420493585`, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.382026634673881, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       4.499809670330265, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.298317366548037, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.703782474656202, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       5.991464547107983, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.396929655216145, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.551080335043405, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.684611727667927, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       6.802394763324311, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}}, {{{0., 
        FormBox["\"0\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
        FormBox["\"1\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
        FormBox["\"2\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
        FormBox["\"3\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
        FormBox["\"4\"", TraditionalForm], {0.01, 0.}, {}}, {0.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       0.6000000000000001, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}, {{0., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {1., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {2., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {3., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {4., 
        FormBox["\"\"", TraditionalForm], {0.01, 0.}, {}}, {0.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {
       0.6000000000000001, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {0.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {1.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {2.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.2, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.4, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.6, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}, {3.8, 
        FormBox["\"\"", TraditionalForm], {0.005, 0.}, {}}}}}],
  GridLines->{None, None},
  ImageSize->216,
  Method->{},
  PlotRange->{{-0.0001, 4}, {-1.1512925464970227`, 5.756462732485114}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.516135758125*^9, {3.51613585696875*^9, 3.516135936375*^9}, 
   3.614203089836568*^9},
 CellLabel->"Out[172]="]
}, Open  ]],

Cell[TextData[{
 "\tAlternatively, if you are a SciDraw user, you might find  yourself \
wanting to include the output of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " in a SciDraw figure, via ",
 StyleBox["FigGraphics",
  FontFamily->"Courier New"],
 ", and then put logarithmic ticks on this figure.  (I generally just use the \
manual approach above, instead, and do not bother with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 ", but you may be a diehard ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " user...)  Similarly, if you are a more advanced Mathematica graphics \
programmer, you might find yourself wishing to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions to generate graphics which you will then combine with other \
graphics to form a composite figure, and you then may wish to put logarithmic \
ticks on this figure.  It turns out that ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and its ilk do essentially what we described as the manual procedure \
above.  That is, they generate linear plots in which they have taken the \
logarithms of the coordinates.  But, they actually take the logarithm base ",
 StyleBox["e",
  FontSlant->"Italic"],
 ", rather than base 10.  (No matter that the ",
 StyleBox["ticks",
  FontSlant->"Italic"],
 " which they generate by default are base 10 log ticks...)  So, if you \
create ticks with ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 ", the coordinates describing where these ticks should be placed must be \
adjusted accordingly.  For instance, the tick for \[OpenCurlyDoubleQuote]10\
\[CloseCurlyDoubleQuote], instead of being located at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]]],
 "10=1 according to the procedure we described before, must now be at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "e"], TraditionalForm]]],
 "10\[TildeTilde]2.30259.  This rescaling of coordinates may be accomplished \
with the option setting ",
 StyleBox["LogPlot->E",
  FontFamily->"Courier New"],
 ".  ",
 StyleBox["Technical note:",
  FontSlant->"Italic"],
 " This option has the same effect as ",
 StyleBox["TickPostTransformation\[Rule](Log[10]*#&)",
  FontFamily->"Courier New"],
 " (see below).  "
}], "Text",
 CellChangeTimes->{{3.614199538286387*^9, 3.614199641146531*^9}, {
  3.6141996870765953`*^9, 3.614199690956601*^9}, {3.61419972583665*^9, 
  3.614200066197126*^9}, {3.614200225417349*^9, 3.614200286197434*^9}, {
  3.6142003400975094`*^9, 3.6142004628276815`*^9}, {3.614200808413165*^9, 
  3.614200825578189*^9}, {3.6142008659782457`*^9, 3.614200898658292*^9}, {
  3.6142010226134653`*^9, 3.6142012821438284`*^9}, {3.614201527019171*^9, 
  3.614201529854175*^9}, {3.6142015704592323`*^9, 3.614201652569347*^9}}],

Cell["",
 PageBreakBelow->True,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.6142016927244034`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Further control over tick placement and advanced customization\
\>", "Subsubsection",
 CellChangeTimes->{{3.52642425421875*^9, 3.526424261453125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TmpMakeHelpBox", "[", 
    RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "Contents___List"}], 
    "]"}], ":=", 
   RowBox[{"MakeColumnBox", "[", 
    RowBox[{"\"\<3ColumnBox\>\"", ",", "3", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ColumnAlignments", "\[Rule]", 
        RowBox[{"{", "Left", "}"}]}], ",", 
       RowBox[{"RowLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}]}], ",", 
       RowBox[{"RowSpacings", "\[Rule]", "1.5"}], ",", 
       RowBox[{"ColumnWidths", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.28", ",", "0.18", ",", "0.5"}], "}"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"StyleBox", "[", 
       RowBox[{"\"\<option name\>\"", ",", "\"\<SO10\>\""}], "]"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"StyleBox", "[", 
       RowBox[{"\"\<default value\>\"", ",", "\"\<SO10\>\""}], "]"}], "}"}], 
     ",", 
     RowBox[{"{", "\"\<\>\"", "}"}], ",", "\[IndentingNewLine]", "Contents"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmpMakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelFunction\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Function used to generate major tick labels (first argument is the \
numerical coordinate, second argument is the \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LinTicks\>\"", "]"}], ",", 
      "\"\< default formatted label); \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], ",", 
      "\"\< gives the default label\>\""}], "}"}], ",", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickPreTransformation\>\"", "]"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Function to be applied to tick coordinates, before range tests \
and label generation\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickPostTransformation\>\"", "]"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Function to be applied to tick coordinates, after range tests \
and label generation\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickIndexTransformation\>\"", "]"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Function to be applied to minor tick indices (originally 1, 2, \
\[Ellipsis], \>\"", ",", 
      RowBox[{"textit", "[", "\"\<subdivs\>\"", "]"}], ",", 
      "\"\<-1) before minor tick coordinate is obtained by linear \
interpolation between major tick positions\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickIndexRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{1,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits drawing of minor ticks to those with indices (before \
tranformation) in given range\>\"", "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Advanced customization options.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[18]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["TickLabelFunction",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "used", " ", "to", " ", "generate", " ", "major", 
         " ", "tick", " ", "labels", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "first", " ", "argument", " ", "is", " ", "the", " ", "numerical", 
            " ", "coordinate"}], ",", " ", 
           RowBox[{"second", " ", "argument", " ", "is", " ", "the", " ", 
            StyleBox["LinTicks",
             FontFamily->"Courier"], " ", 
            RowBox[{"default", " ", "formatted", " ", "label"}]}]}], ")"}]}], 
        ";", " ", 
        RowBox[{
         StyleBox["Automatic",
          FontFamily->"Courier"], " ", 
         RowBox[{"gives", " ", "the", " ", "default", " ", "label"}]}]}]},
      {
       StyleBox["TickPreTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
         "tick", " ", "coordinates"}], ",", " ", 
        RowBox[{
        "before", " ", "range", " ", "tests", " ", "and", " ", "label", " ", 
         "generation"}]}]},
      {
       StyleBox["TickPostTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
         "tick", " ", "coordinates"}], ",", " ", 
        RowBox[{
        "after", " ", "range", " ", "tests", " ", "and", " ", "label", " ", 
         "generation"}]}]},
      {
       StyleBox["MinorTickIndexTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
       "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
        "minor", " ", "tick", " ", "indices", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"originally", " ", "1"}], ",", " ", "2", ",", " ", 
          "\[Ellipsis]", ",", " ", 
          RowBox[{
           StyleBox["subdivs",
            FontSlant->"Italic"], 
           RowBox[{
            RowBox[{
             RowBox[{"-", "1"}], ")"}], " ", "before", " ", "minor", " ", 
            "tick", " ", "coordinate", " ", "is", " ", "obtained", " ", "by", 
            " ", "linear", " ", "interpolation", " ", "between", " ", "major",
             " ", "tick", " ", "positions"}]}]}]}]}]},
      {
       StyleBox["MinorTickIndexRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "drawing", " ", "of", " ", "minor", " ", "ticks", " ", 
        "to", " ", "those", " ", "with", " ", "indices", " ", 
        RowBox[{"(", 
         RowBox[{"before", " ", "tranformation"}], ")"}], " ", "in", " ", 
        "given", " ", "range"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.28], 
       Scaled[0.18], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Advanced customization options.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 "\t",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " accepts several options for advanced customization, allowing fully \
customizable labels and general nonlinear axis scales.  The option ",
 StyleBox["TickLabelFunction",
  FontFamily->"Courier New"],
 " is used to specify the function to be used to construct tick labels (see \
the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for ",
 StyleBox["Function",
  FontFamily->"Courier New"],
 " for information on defining functions).  The label function is given as \
arguments both the raw numerical tick coordinate and the ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " default formatted label, so it can work with whichever is more convenient. \
 The label function may be used for simple tasks, such as attaching a prefix \
or suffix to the usual default label, or for more sophisticated formatting.  \
In the following example, tick values are formatted as rational multiples of \
\[Pi]."
}], "Text"],

Cell["\<\
LinTicks[0,2*Pi,Pi/2,4,TickLabelFunction\[Rule](Rationalize[#/Pi]*Pi&)]\
\>", "Program"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"RawGraphics", "[", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeLine", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "*", "Pi"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"LinTicks", "[", 
       RowBox[{"0", ",", 
        RowBox[{"2", "*", "Pi"}], ",", 
        RowBox[{"Pi", "/", "2"}], ",", "4", ",", 
        RowBox[{"TickLabelFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", 
             RowBox[{"#", "/", "Pi"}], "]"}], "*", "Pi"}], "&"}], ")"}]}]}], 
       "]"}], ",", 
      RowBox[{"LinTicks", "[", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2", ",", "1", ",", "5"}], "]"}], ",", 
      "None", ",", "None"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52642283659375*^9, 3.5264228373125*^9}, 
   3.52642288984375*^9},
 CellLabel->"In[176]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k4lN8bxq1ZEjPvWJOifSWltOA5lUSklGgRmrSQEC1IijYk2VJkS4Xy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      "]]}}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], 
    LineBox[{{1.0842021724855044`*^-19, -2.220446049250313*^-16}, {
     6.283185307179586, -2.220446049250313*^-16}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->{{{0., 
      FormBox["0", TraditionalForm], {0.01, 0}, {}}, {1.5707963267948966`, 
      FormBox[
       FractionBox["\[Pi]", "2"], TraditionalForm], {0.01, 0}, {}}, {
     3.141592653589793, 
      FormBox["\[Pi]", TraditionalForm], {0.01, 0}, {}}, {4.71238898038469, 
      FormBox[
       FractionBox[
        RowBox[{"3", " ", "\[Pi]"}], "2"], TraditionalForm], {0.01, 0}, {}}, {
     6.283185307179586, 
      FormBox[
       RowBox[{"2", " ", "\[Pi]"}], TraditionalForm], {0.01, 0}, {}}, {
     0.39269908169872414`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7853981633974483, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.1780972450961724`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9634954084936207`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.356194490192345, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.748893571891069, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5342917352885173`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.9269908169872414`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.319689898685965, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.105088062083414, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.497787143782138, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.890486225480862, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-2., 
      FormBox["\"-2\"", TraditionalForm], {0.01, 0}, {}}, {-1., 
      FormBox["\"-1\"", TraditionalForm], {0.01, 0}, {}}, {0., 
      FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
      FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
      FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {-1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, None, None},
  ImageSize->NCache[{288, 288/GoldenRatio}, {288, 177.9937887599697}],
  PlotRange->{{-0.0006283185307179586, 
   6.283813625710304}, {-1.1002200000000002`, 1.1002200000000002`}},
  Ticks->None]], "Output",
 CellChangeTimes->{3.526422839546875*^9, 3.52642289253125*^9},
 CellLabel->"Out[176]="]
}, Open  ]],

Cell[TextData[{
 "Nonlinear axes are constructed using the coordinate transformation \
functions.  For instance, the ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " function provided by the CustomTicks package is actually implemented as a \
special case of ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 ", with transformed minor tick positions.  A very simplified implementation \
of ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " (base 10 logarithm only) is given below for illustration."
}], "Text",
 CellChangeTimes->{{3.6142026695450544`*^9, 3.6142026791846056`*^9}, 
   3.614202709320699*^9}],

Cell["\<\
Log10Ticks[p1_Integer,p2_Integer,Opts___?OptionQ]:=LinTicks[
\t  p1,p2,1,9,
      TickLabelFunction\[Rule](DisplayForm[SuperscriptBox[10,IntegerPart[#]]]&\
),
      MinorTickIndexTransformation\[Rule](Log10[#+1]*9&),
      Opts
      ];\
\>", "Program",
 CellChangeTimes->{3.6142026012871504`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<majorticklist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<minorticklist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces major and minor ticks at the specified coordinate \
values\>\"", "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Form of tick specification function for ticks at arbitrary \
locations.\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 Hyphenation->False,
 CellLabel->"In[12]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["majorticklist",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["minorticklist",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
       "Produces", " ", "major", " ", "and", " ", "minor", " ", "ticks", " ", 
        "at", " ", "the", " ", "specified", " ", "coordinate", " ", "values"}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["\<\
Form of tick specification function for ticks at arbitrary locations.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 "\tTicks may be placed at arbitrary coordinate locations by using the most \
flexible form of ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 ", in which all major and minor tick coordinates are specified explicitly in \
two lists.  All the usual coordinate-transformation and customization options \
described above (except ",
 StyleBox["MinorTickIndexRange",
  FontFamily->"Courier New"],
 ") are still applicable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CodeOpts", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ManualLabel", ",", 
       RowBox[{"Offset", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"+", "1"}]}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Bottom", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "6.8"}], "}"}], ",", "0", ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LinTicks", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "5"}], "}"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0.1", ",", "0.9", ",", "0.1"}], "]"}], ",", 
          RowBox[{"MajorTickLength", "\[Rule]", 
           RowBox[{"4", "*", "0.00625"}]}], " ", ",", 
          RowBox[{"MinorTickLength", "\[Rule]", 
           RowBox[{"4", "*", "0.00375"}]}]}], "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{
          RowBox[{"-", "0.2"}], "-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Manual choice of tick coordinates\>\"", "}"}]}], 
        "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{
          RowBox[{"-", "0.2"}], "-", "0.8"}]}], "}"}], ",", 
       "\"\<LinTicks[{0,1,2,3,5},Range[0.1,0.9,0.1]]\>\"", ",", "CodeOpts"}], 
      "]"}], ","}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "7.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.516134924765625*^9},
 CellLabel->"In[6]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.220446049250313*^-16, 0.}, {6.8, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{6.64997, 0.08335000000000004}, {6.800000000000001, 0.}, {
     6.64997, -0.08335000000000004}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {LineBox[{{2.220446049250313*^-16, 0.15003}, {
      2.220446049250313*^-16, 0.}}], 
     LineBox[{{1.0000000000000002`, 0.15003}, {1.0000000000000002`, 0.}}], 
     LineBox[{{2., 0.15003}, {2., 0.}}], LineBox[{{3., 0.15003}, {3., 0.}}], 
     LineBox[{{5., 0.15003}, {5., 0.}}], 
     LineBox[{{0.10000000000000023`, 0.09001799999999999}, {
      0.10000000000000023`, 0.}}], 
     LineBox[{{0.20000000000000023`, 0.09001799999999999}, {
      0.20000000000000023`, 0.}}], 
     LineBox[{{0.30000000000000027`, 0.09001799999999999}, {
      0.30000000000000027`, 0.}}], 
     LineBox[{{0.40000000000000024`, 0.09001799999999999}, {
      0.40000000000000024`, 0.}}], 
     LineBox[{{0.5000000000000002, 0.09001799999999999}, {0.5000000000000002, 
      0.}}], LineBox[{{0.6000000000000003, 0.09001799999999999}, {
      0.6000000000000003, 0.}}], 
     LineBox[{{0.7000000000000003, 0.09001799999999999}, {0.7000000000000003, 
      0.}}], LineBox[{{0.8000000000000003, 0.09001799999999999}, {
      0.8000000000000003, 0.}}], 
     LineBox[{{0.9000000000000002, 0.09001799999999999}, {0.9000000000000002, 
      0.}}]}, InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"0\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.220446049250313*^-16, -0.013891666666666665`}, {0, 1}, 
     Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"1\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {1.0000000000000002`, -0.013891666666666665`}, {0, 1}, 
     Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"2\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2., -0.013891666666666665`}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"3\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -0.013891666666666665`}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"5\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {5., -0.013891666666666665`}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{
           "Manual", " ", "choice", " ", "of", " ", "tick", " ", 
            "coordinates"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -0.5}, {0, 1}, Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LinTicks[{0,1,2,3,5},Range[0.1,0.9,0.1]]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -1.}, {0, 1}, Automatic, {1, 0}]}},
  AspectRatio->NCache[
    Rational[1, 5], 0.2],
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->False,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->None,
  ImageSize->{360, 72},
  PlotRange->{{-1.5009, 7.5009}, {-1.5002, 0.5002}},
  Ticks->None]], "Output",
 CellChangeTimes->{3.51613492528125*^9},
 CellLabel->"Out[6]="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ExtraTicks\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Additional coordinate values at which to insert tick marks\>\"",
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickTest\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<(True&)\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Logical test  to be applied to coordinate values, to select the \
coordinates at which tick marks are displayed (provides further control \
beyond the simple range test provided by \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<TickRange\>\"", "]"}], ",", 
      "\"\< above)\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelTest\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<(True&)\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Logical test to be applied to coordinate values, to select the \
coordinates at which tick labels are displayed (provides further control \
beyond the simple range test provided by \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<TickLabelRange\>\"", "]"}], ",", 
      "\"\< above)\>\""}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Further options controlling the placement of tick marks and \
labels.\>\"", "}"}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52642427871875*^9, 3.526424284765625*^9}},
 CellLabel->"In[244]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["ExtraTicks",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Additional", " ", "coordinate", " ", "values", " ", "at", " ", 
        "which", " ", "to", " ", "insert", " ", "tick", " ", "marks"}]},
      {
       StyleBox["TickTest",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"(", 
         RowBox[{"True", "&"}], ")"}],
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Logical", " ", "test", "  ", "to", " ", "be", " ", "applied", " ", 
         "to", " ", "coordinate", " ", "values"}], ",", " ", 
        RowBox[{
        "to", " ", "select", " ", "the", " ", "coordinates", " ", "at", " ", 
         "which", " ", "tick", " ", "marks", " ", "are", " ", "displayed", 
         " ", 
         RowBox[{"(", 
          RowBox[{
          "provides", " ", "further", " ", "control", " ", "beyond", " ", 
           "the", " ", "simple", " ", "range", " ", "test", " ", "provided", 
           " ", "by", " ", 
           StyleBox["TickRange",
            FontFamily->"Courier"], " ", "above"}], ")"}]}]}]},
      {
       StyleBox["TickLabelTest",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"(", 
         RowBox[{"True", "&"}], ")"}],
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Logical", " ", "test", " ", "to", " ", "be", " ", "applied", " ", 
         "to", " ", "coordinate", " ", "values"}], ",", " ", 
        RowBox[{
        "to", " ", "select", " ", "the", " ", "coordinates", " ", "at", " ", 
         "which", " ", "tick", " ", "labels", " ", "are", " ", "displayed", 
         " ", 
         RowBox[{"(", 
          RowBox[{
          "provides", " ", "further", " ", "control", " ", "beyond", " ", 
           "the", " ", "simple", " ", "range", " ", "test", " ", "provided", 
           " ", "by", " ", 
           StyleBox["TickLabelRange",
            FontFamily->"Courier"], " ", "above"}], ")"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.526424285125*^9}],

Cell["\<\
Further options controlling the placement of tick marks and labels.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.5264242851875*^9}],

Cell["\<\
\tOr, even without taking complete manual control of the choice of tick \
positions, some further control over tick placement is provided through the \
options above.\
\>", "Text",
 CellChangeTimes->{{3.526424696859375*^9, 3.5264247428125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tick mark programming utilities", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LimitTickRange[{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<},\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Selects those tick mark with coordinates in the range \
specified; approximate equality testing is used to avoid dropping ticks at \
the ends of the interval due to roundoff; ticks must be specifies as lists \
rather than bare numbers\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TransformTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<coordfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<lengthfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Applies the specified transformation functions to the tick \
coordinates and tick lengths, respectively; ticks must be specified with an \
explicit pair of in and out lengths\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<StripTickLabels[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Removes any text labels from ticks; ticks must be specified as \
lists rather than bare numbers\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<AugmentTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<labelfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<},\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<stylelist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Upgrades all tick specifications to full specifications, \
complete with labels, lengths into and out of the frame (default 0 for out), \
and style directives\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<AugmentAxisTickOptions[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<numaxes\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<tickoptions\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Given a list of tick options (themselves lists of tick \
specifications) for several axes, replaces any \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<None\>\"", "]"}], ",", 
      "\"\< entries with null lists and appends additional null lists as \
needed to make \>\"", ",", 
      RowBox[{"textit", "[", "\"\<numaxes\>\"", "]"}], ",", 
      "\"\< entries; a value \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<None\>\"", "]"}], ",", "\"\< for \>\"", ",", 
      RowBox[{"textit", "[", "\"\<tickoptions\>\"", "]"}], ",", 
      "\"\< is replaced by a list of null lists\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TickQ[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Tests whether or not \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< is a valid tick mark specificiation\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TickListQ[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Tests whether or not \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< is a list of valid tick mark specificiations\>\""}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Tick manipulation utilities.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.4247279345*^9},
 Hyphenation->False,
 CellLabel->"In[52]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LimitTickRange", "[", "{"}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", ","}],
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Selects", " ", "those", " ", "tick", " ", "mark", " ", "with", " ", 
         "coordinates", " ", "in", " ", "the", " ", "range", " ", 
         "specified"}], ";", " ", 
        RowBox[{
        "approximate", " ", "equality", " ", "testing", " ", "is", " ", 
         "used", " ", "to", " ", "avoid", " ", "dropping", " ", "ticks", " ", 
         "at", " ", "the", " ", "ends", " ", "of", " ", "the", " ", 
         "interval", " ", "due", " ", "to", " ", "roundoff"}], ";", " ", 
        RowBox[{
        "ticks", " ", "must", " ", "be", " ", "specifies", " ", "as", " ", 
         "lists", " ", "rather", " ", "than", " ", "bare", " ", "numbers"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TransformTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["coordfcn",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["lengthfcn",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Applies", " ", "the", " ", "specified", " ", "transformation", " ", 
         "functions", " ", "to", " ", "the", " ", "tick", " ", "coordinates", 
         " ", "and", " ", "tick", " ", "lengths"}], ",", " ", 
        RowBox[{"respectively", ";", " ", 
         RowBox[{
         "ticks", " ", "must", " ", "be", " ", "specified", " ", "with", " ", 
          "an", " ", "explicit", " ", "pair", " ", "of", " ", "in", " ", 
          "and", " ", "out", " ", "lengths"}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"StripTickLabels", "["}],
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Removes", " ", "any", " ", "text", " ", "labels", " ", "from", " ", 
         "ticks"}], ";", " ", 
        RowBox[{
        "ticks", " ", "must", " ", "be", " ", "specified", " ", "as", " ", 
         "lists", " ", "rather", " ", "than", " ", "bare", " ", "numbers"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"AugmentTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["labelfcn",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{",", "{"}],
         FontFamily->"Courier"], 
        StyleBox["l1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["l2",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", ","}],
         FontFamily->"Courier"], 
        StyleBox["stylelist",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Upgrades", " ", "all", " ", "tick", " ", "specifications", " ", "to",
          " ", "full", " ", "specifications"}], ",", " ", 
        RowBox[{"complete", " ", "with", " ", "labels"}], ",", " ", 
        RowBox[{
        "lengths", " ", "into", " ", "and", " ", "out", " ", "of", " ", "the",
          " ", "frame", " ", 
         RowBox[{"(", 
          RowBox[{"default", " ", "0", " ", "for", " ", "out"}], ")"}]}], ",",
         " ", 
        RowBox[{"and", " ", "style", " ", "directives"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"AugmentAxisTickOptions", "["}],
         FontFamily->"Courier"], 
        StyleBox["numaxes",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["tickoptions",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Given", " ", "a", " ", "list", " ", "of", " ", "tick", " ", 
         "options", " ", 
         RowBox[{"(", 
          RowBox[{
          "themselves", " ", "lists", " ", "of", " ", "tick", " ", 
           "specifications"}], ")"}], " ", "for", " ", "several", " ", 
         "axes"}], ",", " ", 
        RowBox[{
         RowBox[{"replaces", " ", "any", " ", 
          StyleBox["None",
           FontFamily->"Courier"], " ", "entries", " ", "with", " ", "null", 
          " ", "lists", " ", "and", " ", "appends", " ", "additional", " ", 
          "null", " ", "lists", " ", "as", " ", "needed", " ", "to", " ", 
          "make", " ", 
          StyleBox["numaxes",
           FontSlant->"Italic"], " ", "entries"}], ";", " ", 
         RowBox[{"a", " ", "value", " ", 
          StyleBox["None",
           FontFamily->"Courier"], " ", "for", " ", 
          StyleBox["tickoptions",
           FontSlant->"Italic"], " ", 
          RowBox[{
          "is", " ", "replaced", " ", "by", " ", "a", " ", "list", " ", "of", 
           " ", "null", " ", "lists"}]}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TickQ", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{"Tests", " ", "whether", " ", "or", " ", "not", " ", 
        StyleBox["x",
         FontSlant->"Italic"], " ", 
        RowBox[{
        "is", " ", "a", " ", "valid", " ", "tick", " ", "mark", " ", 
         "specificiation"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TickListQ", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{"Tests", " ", "whether", " ", "or", " ", "not", " ", 
        StyleBox["x",
         FontSlant->"Italic"], " ", 
        RowBox[{
        "is", " ", "a", " ", "list", " ", "of", " ", "valid", " ", "tick", 
         " ", "mark", " ", "specificiations"}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Tick manipulation utilities.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["\<\
\tSeveral utility functions for tick mark manipulation and testing are \
provided.  These are mainly intended for use in graphics programming rather \
than for direct use by someone wishing to specify tick marks.  They are used \
internally by the LevelScheme figure preparation system.\
\>", "Text",
 CellChangeTimes->{{3.424727971765625*^9, 3.42472797553125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FractionDigits[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Returns the number of digits to the right of the point in the \
decimal representation of \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Decimal digit counting function.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.4247279345*^9},
 Hyphenation->False,
 CellLabel->"In[52]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"FractionDigits", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
       "Returns", " ", "the", " ", "number", " ", "of", " ", "digits", " ", 
        "to", " ", "the", " ", "right", " ", "of", " ", "the", " ", "point", 
        " ", "in", " ", "the", " ", "decimal", " ", "representation", " ", 
        "of", " ", 
        StyleBox["x",
         FontSlant->"Italic"]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Decimal digit counting function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 "\t",
 StyleBox["FractionDigits",
  FontFamily->"Courier New"],
 " determines the number of digits to the right of the point in the decimal \
representation of a number.  It is of use in constructing fixed-point tick \
labels.  It will, naturally, return large values, determined by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Precision",
  FontFamily->"Courier New"],
 ", for some numbers,  such as non-terminating rationals.  It accepts the \
option ",
 StyleBox["FractionDigitsBase",
  FontFamily->"Courier New"],
 ", by default 10, for work with non-decimal representations.  Some examples \
follow:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FractionDigits", "[", "100", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FractionDigits", "[", "1.25", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FractionDigits", "[", 
  RowBox[{"1", "/", "3"}], "]"}]}], "Input",
 CellLabel->"In[441]:="],

Cell[BoxData["0"], "Output",
 CellLabel->"Out[441]="],

Cell[BoxData["2"], "Output",
 CellLabel->"Out[442]="],

Cell[BoxData["17"], "Output",
 CellLabel->"Out[443]="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FixedPointForm[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Formats \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< as a fixed\[Dash]point number with \>\"", ",", " ", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      "\"\<digits to the right of the decimal point.\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FixedPointForm[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<}]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Formats \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< as a fixed\[Dash]point number with \>\"", ",", 
      RowBox[{"textit", "[", "\"\<l\>\"", "]"}], ",", 
      "\"\< digits (or spaces) to the left and \>\"", ",", " ", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      "\"\< digits to the right of the decimal point.\>\""}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Decimal digit counting function.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.4247279345*^9, {3.526423042921875*^9, 3.526423229609375*^9}, {
   3.526423265203125*^9, 3.52642326859375*^9}},
 Hyphenation->False,
 CellLabel->"In[183]:="],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"FixedPointForm", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["r",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{"Formats", " ", 
         StyleBox["x",
          FontSlant->"Italic"], " ", 
         RowBox[{"as", " ", "a", " ", "fixed"}]}], "\[Dash]", 
        RowBox[{"point", " ", "number", " ", "with", " ", 
         StyleBox["r",
          FontSlant->"Italic"], 
         RowBox[{
         "digits", " ", "to", " ", "the", " ", "right", " ", "of", " ", "the",
           " ", "decimal", " ", 
          RowBox[{"point", "."}]}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"FixedPointForm", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{",", "{"}],
         FontFamily->"Courier"], 
        StyleBox["l",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["r",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", "]"}],
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{"Formats", " ", 
         StyleBox["x",
          FontSlant->"Italic"], " ", 
         RowBox[{"as", " ", "a", " ", "fixed"}]}], "\[Dash]", 
        RowBox[{"point", " ", "number", " ", "with", " ", 
         StyleBox["l",
          FontSlant->"Italic"], " ", "digits", " ", 
         RowBox[{"(", 
          RowBox[{"or", " ", "spaces"}], ")"}], " ", "to", " ", "the", " ", 
         "left", " ", "and", " ", 
         StyleBox["r",
          FontSlant->"Italic"], " ", 
         RowBox[{
         "digits", " ", "to", " ", "the", " ", "right", " ", "of", " ", "the",
           " ", "decimal", " ", 
          RowBox[{"point", "."}]}]}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.526423269171875*^9}],

Cell["Decimal digit counting function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.526423269234375*^9}],

Cell[TextData[{
 "\t",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " returns a string, consisting of the real number ",
 StyleBox["x",
  FontSlant->"Italic"],
 " formatted in fixed-point representation.  It is used internally by \
CustomTicks in constructing fixed-point tick labels, hence its inclusion in \
this package, but it may be used to format numbers in many other contexts as \
well.  Some examples follow:"
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423439546875*^9}, {
  3.526423782375*^9, 3.526423794421875*^9}, {3.526423832328125*^9, 
  3.526423881921875*^9}, {3.526424020953125*^9, 3.52642402596875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642368534375*^9, 3.526423733046875*^9}, {
  3.526423899515625*^9, 3.526423909328125*^9}},
 CellLabel->"In[219]:="],

Cell[BoxData["\<\" 3.14159\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.52642390965625*^9}},
 CellLabel->"Out[219]="],

Cell[BoxData["\<\" 3.14\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.526423909703125*^9}},
 CellLabel->"Out[220]="],

Cell[BoxData["\<\" 3\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.52642390975*^9}},
 CellLabel->"Out[221]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"4", "*", "Pi"}], "//", "N"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642368534375*^9, 3.526423726625*^9}, 
   3.526423797734375*^9},
 CellLabel->"In[210]:="],

Cell[BoxData["\<\"  3.142\"\>"], "Output",
 CellChangeTimes->{{3.5264237163125*^9, 3.526423726875*^9}},
 CellLabel->"Out[210]="],

Cell[BoxData["\<\" 12.566\"\>"], "Output",
 CellChangeTimes->{{3.5264237163125*^9, 3.526423726921875*^9}},
 CellLabel->"Out[211]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " accepts options ",
 StyleBox["NumberSigns",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["SignPadding",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["NumberPoint",
  FontFamily->"Courier New"],
 ", which are defined much as for the usual built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " numerical formatting functions ",
 StyleBox["NumberForm",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["etc.",
  FontSlant->"Italic"],
 "  (See the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for further information on their usage.)  By default, for \
positive numbers a blank padding space appears at left, where a minus sign \
would be for negative numbers, to improve alignment with negative numbers.  \
However, ",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " also accepts the special value ",
 StyleBox["NumberSigns\[Rule]Automatic",
  FontFamily->"Courier New"],
 ", which specifies that this space should be suppressed.  In general, this \
provides a better appearance for tick labels. "
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423439546875*^9}, {
  3.526423782375*^9, 3.526423794421875*^9}, {3.526423832328125*^9, 
  3.526423887578125*^9}, {3.52642392653125*^9, 3.52642395121875*^9}, {
  3.6141975712165823`*^9, 3.6141976286304817`*^9}, {3.614197706412218*^9, 
  3.6141977849895563`*^9}, {3.614197827312431*^9, 3.614197883347729*^9}, {
  3.6141982654392004`*^9, 3.614198297575257*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "Pi"}], "//", "N"}], ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "3", ",", 
   RowBox[{"NumberSigns", "->", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642355246875*^9, 3.5264236769375*^9}},
 CellLabel->"In[214]:="],

Cell[BoxData["\<\" 3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.526423736390625*^9},
 CellLabel->"Out[214]="],

Cell[BoxData["\<\"-3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.52642373640625*^9},
 CellLabel->"Out[215]="],

Cell[BoxData["\<\"3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.526423736453125*^9},
 CellLabel->"Out[216]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Technical notes:",
  FontSlant->"Italic"],
 " ",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " allows as many digits as necessary to the left of the decimal point, \
thereby avoiding the rounding problem associated with ",
 StyleBox["PaddedForm[",
  FontFamily->"Courier New"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",{",
  FontFamily->"Courier New"],
 StyleBox["n",
  FontSlant->"Italic"],
 StyleBox[",",
  FontFamily->"Courier New"],
 StyleBox["f",
  FontSlant->"Italic"],
 StyleBox["}]",
  FontFamily->"Courier New"],
 " when ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is specified too small (",
 StyleBox["PaddedForm",
  FontFamily->"Courier New"],
 " zeros out some of the rightmost digits of the number).  It also suppresses \
any trailing decimal point when ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=0."
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423470421875*^9}, {
   3.52642376296875*^9, 3.526423778953125*^9}, 3.5264239686875*^9}],

Cell["\[Copyright] Copyright 2016, Mark A. Caprio.", "Text",
 CellChangeTimes->{
  3.424727901109375*^9, {3.516135675765625*^9, 3.516135675953125*^9}, {
   3.5668384004564514`*^9, 3.5668384054664583`*^9}, {3.6141978905081415`*^9, 
   3.614197890617342*^9}, {3.666801222595255*^9, 3.6668012231568556`*^9}}]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"RulerBar",
WindowSize->{1672, 1017},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{32000, 32000},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData[
     StyleBox[
      RowBox[{"CustomTicks", " ", "package"}], "PageHeader"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2003", " ", "M", ".", " ", "A", ".", " ", "Caprio"}], 
      "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Version", " ", "2.1", ".0"}], "PageFooter"]], "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->False,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792}},
ShowSelection->True,
CellElementSpacings->{"ClosedCellHeight"->1},
ShowCellLabel->False,
LanguageCategory->None,
Magnification->1.5,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 930, 21, 156, "Text"],
Cell[1478, 43, 716, 14, 14, "Text",
 CellOpen->False],
Cell[CellGroupData[{
Cell[2219, 61, 37, 0, 48, "Subsubsection"],
Cell[2259, 63, 672, 12, 75, "Text"],
Cell[2934, 77, 506, 15, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3477, 97, 50, 0, 48, "Subsubsection"],
Cell[3530, 99, 500, 11, 54, "Text"],
Cell[4033, 112, 660, 18, 76, "Text"],
Cell[4696, 132, 11552, 259, 18, "Input",
 CellOpen->False,
 InitializationCell->True],
Cell[16251, 393, 2388, 74, 61, "Text"],
Cell[18642, 469, 137, 3, 20, "Caption"],
Cell[18782, 474, 2145, 61, 91, "Text"],
Cell[20930, 537, 187, 5, 20, "Caption"],
Cell[21120, 544, 3607, 101, 231, "Text"],
Cell[24730, 647, 180, 5, 20, "Caption"],
Cell[24913, 654, 5038, 139, 303, "Text"],
Cell[29954, 795, 157, 3, 30, "Caption"],
Cell[30114, 800, 2742, 77, 253, "Text"],
Cell[32859, 879, 221, 6, 30, "Caption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33117, 890, 41, 0, 72, "Subsubsection"],
Cell[33161, 892, 1010, 37, 87, "Text"],
Cell[34174, 931, 1696, 39, 1, "Input",
 CellOpen->False],
Cell[35873, 972, 2067, 67, 91, "Text"],
Cell[37943, 1041, 107, 2, 30, "Caption"],
Cell[38053, 1045, 1148, 41, 84, "Text"],
Cell[CellGroupData[{
Cell[39226, 1090, 6562, 170, 1, "Input",
 CellOpen->False],
Cell[45791, 1262, 37875, 952, 589, "Output"]
}, Open  ]],
Cell[83681, 2217, 2073, 79, 176, "Text"],
Cell[85757, 2298, 586, 16, 256, "Program"],
Cell[CellGroupData[{
Cell[86368, 2318, 1799, 46, 18, "Input",
 CellOpen->False],
Cell[88170, 2366, 12830, 217, 239, "Output"]
}, Open  ]],
Cell[101015, 2586, 519, 16, 256, "Program"],
Cell[CellGroupData[{
Cell[101559, 2606, 1749, 49, 18, "Input",
 CellOpen->False],
Cell[103311, 2657, 8920, 157, 227, "Output"]
}, Open  ]],
Cell[112246, 2817, 516, 14, 33, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112799, 2836, 243, 7, 48, "Subsubsection"],
Cell[113045, 2845, 562, 15, 55, "Text"],
Cell[113610, 2862, 500, 12, 149, "Program"],
Cell[CellGroupData[{
Cell[114135, 2878, 1357, 38, 18, "Input",
 CellOpen->False],
Cell[115495, 2918, 8943, 180, 226, "Output"]
}, Open  ]],
Cell[124453, 3101, 701, 16, 77, "Text"],
Cell[125157, 3119, 682, 15, 149, "Program"],
Cell[CellGroupData[{
Cell[125864, 3138, 1597, 42, 18, "Input",
 CellOpen->False],
Cell[127464, 3182, 13694, 272, 239, "Output"]
}, Open  ]],
Cell[141173, 3457, 301, 8, 49, "Text"],
Cell[141477, 3467, 540, 9, 94, "Program"],
Cell[CellGroupData[{
Cell[142042, 3480, 1426, 39, 1, "Input",
 CellOpen->False],
Cell[143471, 3521, 31106, 595, 364, "Output"]
}, Open  ]],
Cell[174592, 4119, 1174, 29, 1, "Input",
 CellOpen->False],
Cell[175769, 4150, 1681, 46, 133, "Text"],
Cell[177453, 4198, 188, 7, 31, "Caption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177678, 4210, 168, 6, 73, "Subsubsection"],
Cell[177849, 4218, 1268, 36, 117, "Text"],
Cell[179120, 4256, 644, 15, 255, "Program"],
Cell[CellGroupData[{
Cell[179789, 4275, 1606, 40, 1, "Input",
 CellOpen->False],
Cell[181398, 4317, 24456, 471, 358, "Output"]
}, Open  ]],
Cell[205869, 4791, 2930, 70, 288, "Text"],
Cell[208802, 4863, 123, 4, 48, InheritFromParent,
 PageBreakBelow->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[208962, 4872, 160, 3, 72, "Subsubsection"],
Cell[209125, 4877, 3805, 92, 1, "Input",
 CellOpen->False],
Cell[212933, 4971, 4143, 112, 370, "Text"],
Cell[217079, 5085, 98, 2, 30, "Caption"],
Cell[217180, 5089, 1013, 24, 150, "Text"],
Cell[218196, 5115, 98, 2, 61, "Program"],
Cell[CellGroupData[{
Cell[218319, 5121, 1926, 55, 1, "Input",
 CellOpen->False],
Cell[220248, 5178, 12971, 223, 423, "Output"]
}, Open  ]],
Cell[233234, 5404, 628, 16, 84, "Text"],
Cell[233865, 5422, 307, 9, 223, "Program"],
Cell[234175, 5433, 1013, 25, 1, "Input",
 CellOpen->False],
Cell[235191, 5460, 1416, 41, 52, "Text"],
Cell[236610, 5503, 144, 4, 30, "Caption"],
Cell[236757, 5509, 454, 11, 84, "Text"],
Cell[CellGroupData[{
Cell[237236, 5524, 2582, 69, 1, "Input",
 CellOpen->False],
Cell[239821, 5595, 6075, 175, 184, "Output"]
}, Open  ]],
Cell[245911, 5773, 1936, 43, 1, "Input",
 CellOpen->False],
Cell[247850, 5818, 3141, 85, 253, "Text"],
Cell[250994, 5905, 182, 5, 30, "Caption"],
Cell[251179, 5912, 254, 5, 48, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251470, 5922, 56, 0, 72, "Subsubsection"],
Cell[251529, 5924, 5455, 116, 1, "Input",
 CellOpen->False],
Cell[256987, 6042, 7334, 207, 523, "Text"],
Cell[264324, 6251, 95, 2, 30, "Caption"],
Cell[264422, 6255, 375, 6, 81, "Text"],
Cell[264800, 6263, 938, 25, 1, "Input",
 CellOpen->False],
Cell[265741, 6290, 1435, 41, 52, "Text"],
Cell[267179, 6333, 99, 2, 30, "Caption"],
Cell[267281, 6337, 660, 18, 115, "Text"],
Cell[CellGroupData[{
Cell[267966, 6359, 258, 5, 138, "Input"],
Cell[268227, 6366, 53, 1, 52, "Output"],
Cell[268283, 6369, 53, 1, 52, "Output"],
Cell[268339, 6372, 54, 1, 52, "Output"]
}, Open  ]],
Cell[268408, 6376, 2190, 50, 1, "Input",
 CellOpen->False],
Cell[270601, 6428, 2898, 87, 91, "Text"],
Cell[273502, 6517, 141, 3, 30, "Caption"],
Cell[273646, 6522, 647, 14, 82, "Text"],
Cell[CellGroupData[{
Cell[274318, 6540, 491, 12, 138, "Input"],
Cell[274812, 6554, 133, 2, 52, "Output"],
Cell[274948, 6558, 131, 2, 52, "Output"],
Cell[275082, 6562, 124, 2, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275243, 6569, 471, 14, 97, "Input"],
Cell[275717, 6585, 128, 2, 52, "Output"],
Cell[275848, 6589, 131, 2, 52, "Output"]
}, Open  ]],
Cell[275994, 6594, 1539, 41, 148, "Text"],
Cell[CellGroupData[{
Cell[277558, 6639, 516, 14, 138, "Input"],
Cell[278077, 6655, 203, 3, 52, "Output"],
Cell[278283, 6660, 202, 3, 52, "Output"],
Cell[278488, 6665, 202, 3, 52, "Output"]
}, Open  ]],
Cell[278705, 6671, 1012, 35, 84, "Text"],
Cell[279720, 6708, 305, 4, 48, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
